import * as _hey_api_client_fetch from '@hey-api/client-fetch';
import { TDataShape, Options as Options$1, Client } from '@hey-api/client-fetch';

type ConfigFlag = {
    option: string;
    value: string;
};
type AddressPostalCodeInvalidError = {
    name: string;
    message: string;
};
type AddressFirstLineEmptyError = {
    name: string;
    message: string;
};
type AddressPostalCodeEmptyError = {
    name: string;
    message: string;
};
type AddressCityEmptyError = {
    name: string;
    message: string;
};
type AddressCountryEmptyError = {
    name: string;
    message: string;
};
type Address = {
    address1: string;
    address2: string;
    postalcode: string;
    city: string;
    country: string;
};
type ResponseGroupContact = {
    id: number;
    firstname: string;
    middlename: string;
    lastname: string;
    phone: string;
    email: string;
    groups: {
        [key: string]: unknown;
    };
    address: {
        [key: string]: unknown;
    };
};
type ResponseRunnerGroup = {
    id: number;
    name: string;
    contact?: {
        [key: string]: unknown;
    };
    total_distance?: number;
};
type ResponseRunnerOrganization = {
    address?: {
        [key: string]: unknown;
    };
    teams: Array<unknown>;
    registrationKey?: string;
    registrationEnabled?: boolean;
    id: number;
    name: string;
    contact?: {
        [key: string]: unknown;
    };
    total_distance?: number;
};
type GroupContact = {
    id: number;
    firstname: string;
    middlename?: string;
    lastname: string;
    phone?: string;
    email?: string;
};
type ResponseParticipant = {
    id: number;
    firstname: string;
    middlename: string;
    lastname: string;
    phone: string;
    email: string;
    address?: {
        [key: string]: unknown;
    };
};
type ResponseRunner = {
    distance: number;
    group: {
        [key: string]: unknown;
    };
    id: number;
    firstname: string;
    middlename: string;
    lastname: string;
    phone: string;
    email: string;
    address?: {
        [key: string]: unknown;
    };
};
type ResponseDonor = {
    receiptNeeded: boolean;
    donationAmount: number;
    paidDonationAmount: number;
    id: number;
    firstname: string;
    middlename: string;
    lastname: string;
    phone: string;
    email: string;
    address?: {
        [key: string]: unknown;
    };
};
type ResponseDonation = {
    id: number;
    donor: string;
    amount: number;
    paidAmount: number;
};
type ResponseDistanceDonation = {
    runner: {
        [key: string]: unknown;
    };
    amountPerDistance: number;
    id: number;
    donor: string;
    amount: number;
    paidAmount: number;
};
type Participant = {
    id: number;
    firstname: string;
    middlename?: string;
    lastname: string;
    phone?: string;
    email?: string;
};
type Donor = {
    receiptNeeded: boolean;
    donationAmount: number;
    paidDonationAmount: number;
    id: number;
    firstname: string;
    middlename?: string;
    lastname: string;
    phone?: string;
    email?: string;
};
type Donation = {
    id: number;
    donor: string;
    paidAmount: number;
};
type DistanceDonation = {
    runner: string;
    amountPerDistance: number;
    id: number;
    donor: string;
    paidAmount: number;
};
type RunnerCardNotFoundError = {
    name: string;
    message: string;
};
type RunnerCardIdsNotMatchingError = {
    name: string;
    message: string;
};
type RunnerCardHasScansError = {
    name: string;
    message: string;
};
type RunnerCardIdOutOfRangeError = {
    name: string;
    message: string;
};
type ResponseRunnerCard = {
    id: number;
    runner: {
        [key: string]: unknown;
    };
    code: string;
    enabled: boolean;
};
type ResponseScan = {
    id: number;
    runner: string;
    valid: boolean;
    distance: number;
};
type TrackNotFoundError = {
    name: string;
    message: string;
};
type TrackIdsNotMatchingError = {
    name: string;
    message: string;
};
type TrackLapTimeCantBeNegativeError = {
    name: string;
    message: string;
};
type TrackHasScanStationsError = {
    name: string;
    message: string;
};
type ResponseTrack = {
    id: number;
    name: string;
    distance: number;
    minimumLapTime?: number;
};
type ResponseScanStation = {
    id: number;
    description?: string;
    key?: string;
    prefix: string;
    track: {
        [key: string]: unknown;
    };
    enabled: boolean;
};
type ResponseTrackScan = {
    track: string;
    card: string;
    station: string;
    timestamp: string;
    lapTime: number;
    id: number;
    runner: string;
    valid: boolean;
    distance: number;
};
type Scan = {
    id: number;
    runner: string;
    valid: boolean;
    _distance: number;
    distance: number;
};
type Track = {
    id: number;
    name: string;
    distance: number;
    minimumLapTime?: number;
};
type ScanStation = {
    id: number;
    description?: string;
    track: string;
    prefix: string;
    key: string;
    cleartextkey?: string;
    enabled: boolean;
};
type TrackScan = {
    track: string;
    card: string;
    station: string;
    distance: number;
    timestamp: number;
    lapTime: number;
    id: number;
    runner: string;
    valid: boolean;
    _distance: number;
};
type RunnerCard = {
    id: number;
    runner?: unknown;
    enabled: boolean;
};
type Runner = {
    group: string;
    resetRequestedTimestamp?: string;
    distance: number;
    distanceDonationAmount: number;
    id: number;
    firstname: string;
    middlename?: string;
    lastname: string;
    phone?: string;
    email?: string;
};
type RunnerGroup = {
    id: number;
    name: string;
    contact?: unknown;
    distance: number;
    distanceDonationAmount: number;
};
type ResponseRunnerTeam = {
    parentGroup: {
        [key: string]: unknown;
    };
    id: number;
    name: string;
    contact?: {
        [key: string]: unknown;
    };
    total_distance?: number;
};
type RunnerTeam = {
    parentGroup: string;
    id: number;
    name: string;
    contact?: unknown;
    distance: number;
    distanceDonationAmount: number;
};
type RunnerOrganization = {
    address?: unknown;
    key?: string;
    distance: number;
    distanceDonationAmount: number;
    id: number;
    name: string;
    contact?: unknown;
};
type GroupContactNotFoundError = {
    name: string;
    message: string;
};
type GroupContactIdsNotMatchingError = {
    name: string;
    message: string;
};
type CreateRunnerGroup = {
    name: string;
    contact?: number;
};
type CreateRunnerOrganization = {
    address?: {
        [key: string]: unknown;
    };
    registrationEnabled?: boolean;
    name: string;
    contact?: number;
};
type RunnerGroupNotFoundError = {
    name: string;
    message: string;
};
type CreateGroupContact = {
    firstname: string;
    middlename?: string;
    lastname: string;
    address?: {
        [key: string]: unknown;
    };
    phone?: string;
    email?: string;
    groups?: unknown;
};
type RunnerOrganizationNotFoundError = {
    name: string;
    message: string;
};
type RunnerOrganizationIdsNotMatchingError = {
    name: string;
    message: string;
};
type RunnerOrganizationHasRunnersError = {
    name: string;
    message: string;
};
type RunnerOrganizationHasTeamsError = {
    name: string;
    message: string;
};
type RunnerOrganizationWrongTypeError = {
    name: string;
    message: string;
};
type RunnerTeamNotFoundError = {
    name: string;
    message: string;
};
type RunnerTeamIdsNotMatchingError = {
    name: string;
    message: string;
};
type RunnerTeamHasRunnersError = {
    name: string;
    message: string;
};
type RunnerTeamNeedsParentError = {
    name: string;
    message: string;
};
type CreateParticipant = {
    firstname: string;
    middlename?: string;
    lastname: string;
    phone?: string;
    email?: string;
    address?: {
        [key: string]: unknown;
    };
};
type CreateRunner = {
    group: number;
    firstname: string;
    middlename?: string;
    lastname: string;
    phone?: string;
    email?: string;
    address?: {
        [key: string]: unknown;
    };
};
type CreateRunnerTeam = {
    parentGroup: number;
    name: string;
    contact?: number;
};
type PrincipalNotFoundError = {
    name: string;
    message: string;
};
type PrincipalWrongTypeError = {
    name: string;
    message: string;
};
type ResponsePrincipal = {
    id: number;
};
type ResponsePermission = {
    id: number;
    principal: {
        [key: string]: unknown;
    };
    target: 'RUNNER' | 'ORGANIZATION' | 'TEAM' | 'TRACK' | 'USER' | 'USERGROUP' | 'PERMISSION' | 'STATSCLIENT' | 'DONOR' | 'SCAN' | 'STATION' | 'CARD' | 'DONATION' | 'CONTACT' | 'MAIL';
    action: 'GET' | 'CREATE' | 'UPDATE' | 'DELETE' | 'IMPORT';
};
type Principal = {
    id: number;
};
type Permission = {
    id: number;
    target: 'RUNNER' | 'ORGANIZATION' | 'TEAM' | 'TRACK' | 'USER' | 'USERGROUP' | 'PERMISSION' | 'STATSCLIENT' | 'DONOR' | 'SCAN' | 'STATION' | 'CARD' | 'DONATION' | 'CONTACT' | 'MAIL';
    action: 'GET' | 'CREATE' | 'UPDATE' | 'DELETE' | 'IMPORT';
};
type CreatePermission = {
    principal: number;
    target: 'RUNNER' | 'ORGANIZATION' | 'TEAM' | 'TRACK' | 'USER' | 'USERGROUP' | 'PERMISSION' | 'STATSCLIENT' | 'DONOR' | 'SCAN' | 'STATION' | 'CARD' | 'DONATION' | 'CONTACT' | 'MAIL';
    action: 'GET' | 'CREATE' | 'UPDATE' | 'DELETE' | 'IMPORT';
};
type ResponseUserGroup = {
    name: string;
    description?: string;
    permissions?: Array<unknown>;
    id: number;
};
type UserGroup = {
    name: string;
    description?: string;
    id: number;
};
type CreateUserGroup = {
    name: string;
    description?: string;
};
type ResponseUser = {
    firstname: string;
    middlename: string;
    lastname: string;
    phone: string;
    email: string;
    username: string;
    enabled: boolean;
    profilePic: string;
    groups?: Array<unknown>;
    permissions?: Array<unknown>;
    id: number;
};
type UserAction = {
    id: number;
    target: string;
    action: 'GET' | 'CREATE' | 'UPDATE' | 'DELETE' | 'IMPORT';
    changed?: string;
};
type User = {
    uuid: string;
    email: string;
    phone?: string;
    username: string;
    firstname: string;
    middlename?: string;
    lastname: string;
    password: string;
    groups?: unknown;
    enabled: boolean;
    refreshTokenCount: number;
    profilePic: string;
    resetRequestedTimestamp?: string;
    actions?: unknown;
    id: number;
};
type IllegalJwtError = {
    name: string;
    message: string;
};
type UserNonexistantOrRefreshtokenInvalidError = {
    name: string;
    message: string;
};
type InvalidCredentialsError = {
    name: string;
    message: string;
};
type NoPermissionError = {
    name: string;
    message: string;
};
type UsernameOrEmailNeededError = {
    name: string;
    message: string;
};
type PasswordNeededError = {
    name: string;
    message: string;
};
type UserNotFoundError = {
    name: string;
    message: string;
};
type JwtNotProvidedError = {
    name: string;
    message: string;
};
type UserNotFoundOrRefreshTokenCountInvalidError = {
    name: string;
    message: string;
};
type RefreshTokenCountInvalidError = {
    name: string;
    message: string;
};
type ResetAlreadyRequestedError = {
    name: string;
    message: string;
};
type UserDisabledError = {
    name: string;
    message: string;
};
type JwtUser = {
    id: number;
    uuid: string;
    email?: string;
    username?: string;
    firstname: string;
    middlename?: string;
    lastname: string;
    enabled: boolean;
    refreshTokenCount: number;
    profilePic?: string;
};
type MailSendingError = {
    name: string;
    message: string;
};
type UsernameContainsIllegalCharacterError = {
    name: string;
    message: string;
};
type UserEmailNeededError = {
    name: string;
    message: string;
};
type UserIdsNotMatchingError = {
    name: string;
    message: string;
};
type UserDeletionNotConfirmedError = {
    name: string;
    message: string;
};
type PasswordMustContainUppercaseLetterError = {
    name: string;
    message: string;
};
type PasswordMustContainLowercaseLetterError = {
    name: string;
    message: string;
};
type PasswordMustContainNumberError = {
    name: string;
    message: string;
};
type PasswordTooShortError = {
    name: string;
    message: string;
};
type ResponseAuth = {
    access_token: string;
    refresh_token: string;
    access_token_expires_at: number;
    refresh_token_expires_at: number;
};
type CreateAuth = {
    username?: string;
    email?: string;
    password: string;
};
type CreateResetToken = {
    email: string;
};
type Logout = {
    timestamp: string;
};
type HandleLogout = {
    token?: string;
};
type RefreshAuth = {
    token?: string;
};
type ResetPassword = {
    resetToken?: string;
    password: string;
};
type ResponseEmpty = {
    response: string;
};
type DonationNotFoundError = {
    name: string;
    message: string;
};
type DonationIdsNotMatchingError = {
    name: string;
    message: string;
};
type DonorNotFoundError = {
    name: string;
    message: string;
};
type DonorIdsNotMatchingError = {
    name: string;
    message: string;
};
type DonorReceiptAddressNeededError = {
    name: string;
    message: string;
};
type DonorHasDonationsError = {
    name: string;
    message: string;
};
type RunnerNotFoundError = {
    name: string;
    message: string;
};
type RunnerIdsNotMatchingError = {
    name: string;
    message: string;
};
type RunnerGroupNeededError = {
    name: string;
    message: string;
};
type RunnerEmailNeededError = {
    name: string;
    message: string;
};
type RunnerSelfserviceTimeoutError = {
    name: string;
    message: string;
};
type RunnerHasDistanceDonationsError = {
    name: string;
    message: string;
};
type CreateDonation = {
    donor: number;
    paidAmount?: number;
};
type CreateDistanceDonation = {
    runner: number;
    amountPerDistance: number;
    donor: number;
    paidAmount?: number;
};
type FixedDonation = {
    _amount: number;
    amount: number;
    id: number;
    donor: string;
    paidAmount: number;
};
type CreateFixedDonation = {
    amount: number;
    donor: number;
    paidAmount?: number;
};
type UpdateDonation = {
    id: number;
    donor: number;
    paidAmount?: number;
};
type UpdateDistanceDonation = {
    runner: number;
    amountPerDistance: number;
    id: number;
    donor: number;
    paidAmount?: number;
};
type UpdateFixedDonation = {
    amount: number;
    id: number;
    donor: number;
    paidAmount?: number;
};
type CreateDonor = {
    receiptNeeded?: boolean;
    firstname: string;
    middlename?: string;
    lastname: string;
    phone?: string;
    email?: string;
    address?: {
        [key: string]: unknown;
    };
};
type UpdateDonor = {
    id: number;
    receiptNeeded?: boolean;
    firstname: string;
    middlename?: string;
    lastname: string;
    phone?: string;
    email?: string;
    address?: {
        [key: string]: unknown;
    };
};
type UpdateGroupContact = {
    id: number;
    firstname: string;
    middlename?: string;
    lastname: string;
    address?: {
        [key: string]: unknown;
    };
    phone?: string;
    email?: string;
    groups?: unknown;
};
type ImportRunner = {
    firstname: string;
    middlename?: string;
    lastname: string;
    team?: string;
    class?: string;
};
type UpdateRunner = {
    id: number;
    group: number;
    firstname: string;
    middlename?: string;
    lastname: string;
    phone?: string;
    email?: string;
    address?: {
        [key: string]: unknown;
    };
};
type CreateRunnerCard = {
    runner?: number;
    enabled: boolean;
};
type UpdateRunnerCard = {
    id: number;
    runner?: number;
    enabled: boolean;
};
type ScanNotFoundError = {
    name: string;
    message: string;
};
type ScanIdsNotMatchingError = {
    name: string;
    message: string;
};
type ScanStationNotFoundError = {
    name: string;
    message: string;
};
type ScanStationIdsNotMatchingError = {
    name: string;
    message: string;
};
type ScanStationHasScansError = {
    name: string;
    message: string;
};
type CreateScan = {
    runner: number;
    valid?: boolean;
    distance: number;
};
type CreateTrackScan = {
    card: number;
    station?: number;
};
type UpdateScan = {
    id: number;
    runner: number;
    valid?: boolean;
    distance: number;
};
type UpdateTrackScan = {
    id: number;
    runner: number;
    valid?: boolean;
    track: number;
};
type GroupNameNeededError = {
    name: string;
    message: string;
};
type UserGroupNotFoundError = {
    name: string;
    message: string;
};
type UserGroupIdsNotMatchingError = {
    name: string;
    message: string;
};
type UpdateUser = {
    id: number;
    firstname: string;
    middlename?: string;
    lastname: string;
    username?: string;
    email: string;
    phone?: string;
    password?: string;
    enabled?: boolean;
    groups?: unknown;
    profilePic?: string;
};
type ResponseUserPermissions = {
    directlyGranted?: Array<unknown>;
    inherited?: Array<unknown>;
};
type PermissionNotFoundError = {
    name: string;
    message: string;
};
type PermissionIdsNotMatchingError = {
    name: string;
    message: string;
};
type PermissionNeedsPrincipalError = {
    name: string;
    message: string;
};
type UpdatePermission = {
    id: number;
    principal: number;
    target: string;
    action: string;
};
type UpdateRunnerOrganization = {
    id: number;
    address?: {
        [key: string]: unknown;
    };
    registrationEnabled?: boolean;
    name: string;
    contact?: number;
};
type UpdateRunnerTeam = {
    id: number;
    parentGroup: number;
    name: string;
    contact?: number;
};
type CreateSelfServiceCitizenRunner = {
    email?: string;
    firstname: string;
    middlename?: string;
    lastname: string;
    phone?: string;
    address?: {
        [key: string]: unknown;
    };
};
type CreateSelfServiceRunner = {
    team?: number;
    firstname: string;
    middlename?: string;
    lastname: string;
    phone?: string;
    email?: string;
    address?: {
        [key: string]: unknown;
    };
};
type ResponseSelfServiceTeam = {
    name: string;
    id: number;
};
type ResponseSelfServiceOrganisation = {
    name: string;
    teams: Array<unknown>;
};
type ResponseSelfServiceDonor = {
    id: number;
    firstname: string;
    middlename: string;
    lastname: string;
};
type ResponseSelfServiceDonation = {
    donor: string;
    amount: number;
    amountPerDistance: number;
};
type ResponseSelfServiceRunner = {
    distance: number;
    donationAmount: number;
    group: string;
    distanceDonations: string;
    token?: string;
    id: number;
    firstname: string;
    middlename: string;
    lastname: string;
    phone: string;
    email: string;
    address?: {
        [key: string]: unknown;
    };
};
type ResponseSelfServiceScan = {
    id: number;
    valid: boolean;
    distance: number;
    lapTime: number;
};
type CreateScanStation = {
    description?: string;
    track: number;
    enabled?: boolean;
};
type UpdateScanStation = {
    id: number;
    description?: string;
    enabled?: boolean;
};
type StatsClientNotFoundError = {
    name: string;
    message: string;
};
type StatsClientIdsNotMatchingError = {
    name: string;
    message: string;
};
type ResponseStatsClient = {
    id: number;
    description?: string;
    key?: string;
    prefix: string;
};
type StatsClient = {
    id: number;
    description?: string;
    prefix: string;
    key: string;
    cleartextkey?: string;
};
type CreateStatsClient = {
    description?: string;
};
type ResponseStats = {
    total_runners: number;
    total_teams: number;
    total_orgs: number;
    total_users: number;
    total_scans: number;
    total_distance: number;
    total_donation: number;
    total_donations: number;
    total_donors: number;
    average_distance: number;
    average_donation: number;
};
type ResponseStatsOrgnisation = {
    id: number;
    name: string;
    distance: number;
    donationAmount: number;
};
type ResponseStatsRunner = {
    id: number;
    firstname: string;
    middlename: string;
    lastname: string;
    distance: number;
    donationAmount: number;
    minLaptime?: number;
    group: {
        [key: string]: unknown;
    };
};
type ResponseStatsTeam = {
    id: number;
    name: string;
    distance: number;
    donationAmount: number;
    parent: {
        [key: string]: unknown;
    };
};
type CreateTrack = {
    name: string;
    distance: number;
    minimumLapTime?: number;
};
type UpdateTrack = {
    id: number;
    name: string;
    distance: number;
    minimumLapTime?: number;
};
type CreateUser = {
    firstname: string;
    middlename?: string;
    lastname: string;
    username?: string;
    email: string;
    phone?: string;
    password: string;
    enabled?: boolean;
    groups?: unknown;
    profilePic?: string;
};
type UpdateUserGroup = {
    id: number;
    name: string;
    description?: string;
};
type ResponseUserGroupPermissions = {
    directlyGranted?: Array<unknown>;
    inherited?: Array<unknown>;
};
type AuthControllerLoginData = {
    /**
     * CreateAuth
     */
    body?: CreateAuth;
    path?: never;
    query?: never;
    url: '/api/auth/login';
};
type AuthControllerLoginResponses = {
    200: ResponseAuth | InvalidCredentialsError | UserNotFoundError | UsernameOrEmailNeededError | PasswordNeededError;
};
type AuthControllerLoginResponse = AuthControllerLoginResponses[keyof AuthControllerLoginResponses];
type AuthControllerLogoutData = {
    /**
     * HandleLogout
     */
    body?: HandleLogout;
    path?: never;
    query?: never;
    url: '/api/auth/logout';
};
type AuthControllerLogoutResponses = {
    200: Logout | InvalidCredentialsError | UserNotFoundError | UsernameOrEmailNeededError | PasswordNeededError;
};
type AuthControllerLogoutResponse = AuthControllerLogoutResponses[keyof AuthControllerLogoutResponses];
type AuthControllerRefreshData = {
    /**
     * RefreshAuth
     */
    body?: RefreshAuth;
    path?: never;
    query?: never;
    url: '/api/auth/refresh';
};
type AuthControllerRefreshResponses = {
    200: ResponseAuth | JwtNotProvidedError | IllegalJwtError | UserNotFoundError | RefreshTokenCountInvalidError;
};
type AuthControllerRefreshResponse = AuthControllerRefreshResponses[keyof AuthControllerRefreshResponses];
type AuthControllerGetResetTokenData = {
    /**
     * CreateResetToken
     */
    body?: CreateResetToken;
    path?: never;
    query?: {
        locale?: string;
    };
    url: '/api/auth/reset';
};
type AuthControllerGetResetTokenErrors = {
    404: UserNotFoundError;
    406: UsernameOrEmailNeededError;
    500: MailSendingError;
};
type AuthControllerGetResetTokenError = AuthControllerGetResetTokenErrors[keyof AuthControllerGetResetTokenErrors];
type AuthControllerGetResetTokenResponses = {
    200: ResponseEmpty;
};
type AuthControllerGetResetTokenResponse = AuthControllerGetResetTokenResponses[keyof AuthControllerGetResetTokenResponses];
type AuthControllerResetPasswordData = {
    /**
     * ResetPassword
     */
    body?: ResetPassword;
    path: {
        token: string;
    };
    query?: never;
    url: '/api/auth/reset/{token}';
};
type AuthControllerResetPasswordResponses = {
    200: ResponseAuth | UserNotFoundError | UsernameOrEmailNeededError;
};
type AuthControllerResetPasswordResponse = AuthControllerResetPasswordResponses[keyof AuthControllerResetPasswordResponses];
type DonationControllerGetAllData = {
    body?: never;
    path?: never;
    query?: {
        page?: number;
        page_size?: number;
    };
    url: '/api/donations';
};
type DonationControllerGetAllResponses = {
    200: Array<ResponseDonation> | Array<ResponseDistanceDonation>;
};
type DonationControllerGetAllResponse = DonationControllerGetAllResponses[keyof DonationControllerGetAllResponses];
type DonationControllerRemoveData = {
    body?: never;
    path: {
        id: number;
    };
    query?: {
        force?: boolean;
    };
    url: '/api/donations/{id}';
};
type DonationControllerRemoveResponses = {
    200: ResponseDonation | ResponseDistanceDonation;
    204: ResponseEmpty;
};
type DonationControllerRemoveResponse = DonationControllerRemoveResponses[keyof DonationControllerRemoveResponses];
type DonationControllerGetOneData = {
    body?: never;
    path: {
        id: number;
    };
    query?: never;
    url: '/api/donations/{id}';
};
type DonationControllerGetOneErrors = {
    404: DonationNotFoundError;
};
type DonationControllerGetOneError = DonationControllerGetOneErrors[keyof DonationControllerGetOneErrors];
type DonationControllerGetOneResponses = {
    200: ResponseDonation | ResponseDistanceDonation;
};
type DonationControllerGetOneResponse = DonationControllerGetOneResponses[keyof DonationControllerGetOneResponses];
type DonationControllerPostFixedData = {
    /**
     * CreateFixedDonation
     */
    body?: CreateFixedDonation;
    path?: never;
    query?: never;
    url: '/api/donations/fixed';
};
type DonationControllerPostFixedErrors = {
    404: DonorNotFoundError;
};
type DonationControllerPostFixedError = DonationControllerPostFixedErrors[keyof DonationControllerPostFixedErrors];
type DonationControllerPostFixedResponses = {
    200: ResponseDonation;
};
type DonationControllerPostFixedResponse = DonationControllerPostFixedResponses[keyof DonationControllerPostFixedResponses];
type DonationControllerPostDistanceData = {
    /**
     * CreateDistanceDonation
     */
    body?: CreateDistanceDonation;
    path?: never;
    query?: never;
    url: '/api/donations/distance';
};
type DonationControllerPostDistanceErrors = {
    404: DonorNotFoundError | RunnerNotFoundError;
};
type DonationControllerPostDistanceError = DonationControllerPostDistanceErrors[keyof DonationControllerPostDistanceErrors];
type DonationControllerPostDistanceResponses = {
    200: ResponseDistanceDonation;
};
type DonationControllerPostDistanceResponse = DonationControllerPostDistanceResponses[keyof DonationControllerPostDistanceResponses];
type DonationControllerPutFixedData = {
    /**
     * UpdateFixedDonation
     */
    body?: UpdateFixedDonation;
    path: {
        id: number;
    };
    query?: never;
    url: '/api/donations/fixed/{id}';
};
type DonationControllerPutFixedErrors = {
    404: DonationNotFoundError | DonorNotFoundError | RunnerNotFoundError;
    406: DonationIdsNotMatchingError;
};
type DonationControllerPutFixedError = DonationControllerPutFixedErrors[keyof DonationControllerPutFixedErrors];
type DonationControllerPutFixedResponses = {
    200: ResponseDonation;
};
type DonationControllerPutFixedResponse = DonationControllerPutFixedResponses[keyof DonationControllerPutFixedResponses];
type DonationControllerPutDistanceData = {
    /**
     * UpdateDistanceDonation
     */
    body?: UpdateDistanceDonation;
    path: {
        id: number;
    };
    query?: never;
    url: '/api/donations/distance/{id}';
};
type DonationControllerPutDistanceErrors = {
    404: DonationNotFoundError | DonorNotFoundError | RunnerNotFoundError;
    406: DonationIdsNotMatchingError;
};
type DonationControllerPutDistanceError = DonationControllerPutDistanceErrors[keyof DonationControllerPutDistanceErrors];
type DonationControllerPutDistanceResponses = {
    200: ResponseDonation;
};
type DonationControllerPutDistanceResponse = DonationControllerPutDistanceResponses[keyof DonationControllerPutDistanceResponses];
type DonorControllerGetAllData = {
    body?: never;
    path?: never;
    query?: {
        page?: number;
        page_size?: number;
    };
    url: '/api/donors';
};
type DonorControllerGetAllResponses = {
    200: Array<ResponseDonor>;
};
type DonorControllerGetAllResponse = DonorControllerGetAllResponses[keyof DonorControllerGetAllResponses];
type DonorControllerPostData = {
    /**
     * CreateDonor
     */
    body?: CreateDonor;
    path?: never;
    query?: never;
    url: '/api/donors';
};
type DonorControllerPostResponses = {
    200: ResponseDonor;
};
type DonorControllerPostResponse = DonorControllerPostResponses[keyof DonorControllerPostResponses];
type DonorControllerRemoveData = {
    body?: never;
    path: {
        id: number;
    };
    query?: {
        force?: boolean;
    };
    url: '/api/donors/{id}';
};
type DonorControllerRemoveResponses = {
    200: ResponseDonor;
    204: ResponseEmpty;
};
type DonorControllerRemoveResponse = DonorControllerRemoveResponses[keyof DonorControllerRemoveResponses];
type DonorControllerGetOneData = {
    body?: never;
    path: {
        id: number;
    };
    query?: never;
    url: '/api/donors/{id}';
};
type DonorControllerGetOneErrors = {
    404: DonorNotFoundError;
};
type DonorControllerGetOneError = DonorControllerGetOneErrors[keyof DonorControllerGetOneErrors];
type DonorControllerGetOneResponses = {
    200: ResponseDonor;
};
type DonorControllerGetOneResponse = DonorControllerGetOneResponses[keyof DonorControllerGetOneResponses];
type DonorControllerPutData = {
    /**
     * UpdateDonor
     */
    body?: UpdateDonor;
    path: {
        id: number;
    };
    query?: never;
    url: '/api/donors/{id}';
};
type DonorControllerPutErrors = {
    404: DonorNotFoundError;
    406: DonorIdsNotMatchingError;
};
type DonorControllerPutError = DonorControllerPutErrors[keyof DonorControllerPutErrors];
type DonorControllerPutResponses = {
    200: ResponseDonor;
};
type DonorControllerPutResponse = DonorControllerPutResponses[keyof DonorControllerPutResponses];
type GroupContactControllerGetAllData = {
    body?: never;
    path?: never;
    query?: {
        page?: number;
        page_size?: number;
    };
    url: '/api/contacts';
};
type GroupContactControllerGetAllResponses = {
    200: Array<ResponseGroupContact>;
};
type GroupContactControllerGetAllResponse = GroupContactControllerGetAllResponses[keyof GroupContactControllerGetAllResponses];
type GroupContactControllerPostData = {
    /**
     * CreateGroupContact
     */
    body?: CreateGroupContact;
    path?: never;
    query?: never;
    url: '/api/contacts';
};
type GroupContactControllerPostErrors = {
    404: RunnerGroupNotFoundError;
};
type GroupContactControllerPostError = GroupContactControllerPostErrors[keyof GroupContactControllerPostErrors];
type GroupContactControllerPostResponses = {
    200: ResponseGroupContact;
};
type GroupContactControllerPostResponse = GroupContactControllerPostResponses[keyof GroupContactControllerPostResponses];
type GroupContactControllerRemoveData = {
    body?: never;
    path: {
        id: number;
    };
    query?: {
        force?: boolean;
    };
    url: '/api/contacts/{id}';
};
type GroupContactControllerRemoveResponses = {
    200: ResponseGroupContact;
    204: ResponseEmpty;
};
type GroupContactControllerRemoveResponse = GroupContactControllerRemoveResponses[keyof GroupContactControllerRemoveResponses];
type GroupContactControllerGetOneData = {
    body?: never;
    path: {
        id: number;
    };
    query?: never;
    url: '/api/contacts/{id}';
};
type GroupContactControllerGetOneErrors = {
    404: GroupContactNotFoundError;
};
type GroupContactControllerGetOneError = GroupContactControllerGetOneErrors[keyof GroupContactControllerGetOneErrors];
type GroupContactControllerGetOneResponses = {
    200: ResponseGroupContact;
};
type GroupContactControllerGetOneResponse = GroupContactControllerGetOneResponses[keyof GroupContactControllerGetOneResponses];
type GroupContactControllerPutData = {
    /**
     * UpdateGroupContact
     */
    body?: UpdateGroupContact;
    path: {
        id: number;
    };
    query?: never;
    url: '/api/contacts/{id}';
};
type GroupContactControllerPutErrors = {
    404: GroupContactNotFoundError | RunnerGroupNotFoundError;
    406: GroupContactIdsNotMatchingError;
};
type GroupContactControllerPutError = GroupContactControllerPutErrors[keyof GroupContactControllerPutErrors];
type GroupContactControllerPutResponses = {
    200: ResponseGroupContact;
};
type GroupContactControllerPutResponse = GroupContactControllerPutResponses[keyof GroupContactControllerPutResponses];
type ScanControllerGetAllData = {
    body?: never;
    path?: never;
    query?: {
        page?: number;
        page_size?: number;
    };
    url: '/api/scans';
};
type ScanControllerGetAllResponses = {
    200: Array<ResponseScan> | Array<ResponseTrackScan>;
};
type ScanControllerGetAllResponse = ScanControllerGetAllResponses[keyof ScanControllerGetAllResponses];
type ScanControllerPostData = {
    /**
     * CreateScan
     */
    body?: CreateScan;
    path?: never;
    query?: never;
    url: '/api/scans';
};
type ScanControllerPostErrors = {
    404: RunnerNotFoundError;
};
type ScanControllerPostError = ScanControllerPostErrors[keyof ScanControllerPostErrors];
type ScanControllerPostResponses = {
    200: ResponseScan;
};
type ScanControllerPostResponse = ScanControllerPostResponses[keyof ScanControllerPostResponses];
type ScanControllerRemoveData = {
    body?: never;
    path: {
        id: number;
    };
    query?: {
        force?: boolean;
    };
    url: '/api/scans/{id}';
};
type ScanControllerRemoveResponses = {
    200: ResponseScan;
    204: ResponseEmpty;
};
type ScanControllerRemoveResponse = ScanControllerRemoveResponses[keyof ScanControllerRemoveResponses];
type ScanControllerGetOneData = {
    body?: never;
    path: {
        id: number;
    };
    query?: never;
    url: '/api/scans/{id}';
};
type ScanControllerGetOneErrors = {
    404: ScanNotFoundError;
};
type ScanControllerGetOneError = ScanControllerGetOneErrors[keyof ScanControllerGetOneErrors];
type ScanControllerGetOneResponses = {
    200: ResponseScan | ResponseTrackScan;
};
type ScanControllerGetOneResponse = ScanControllerGetOneResponses[keyof ScanControllerGetOneResponses];
type ScanControllerPutData = {
    /**
     * UpdateScan
     */
    body?: UpdateScan;
    path: {
        id: number;
    };
    query?: never;
    url: '/api/scans/{id}';
};
type ScanControllerPutErrors = {
    404: ScanNotFoundError | RunnerNotFoundError;
    406: ScanIdsNotMatchingError;
};
type ScanControllerPutError = ScanControllerPutErrors[keyof ScanControllerPutErrors];
type ScanControllerPutResponses = {
    200: ResponseScan;
};
type ScanControllerPutResponse = ScanControllerPutResponses[keyof ScanControllerPutResponses];
type ScanControllerPostTrackScansData = {
    /**
     * CreateTrackScan
     */
    body?: CreateTrackScan;
    path?: never;
    query?: never;
    url: '/api/scans/trackscans';
};
type ScanControllerPostTrackScansErrors = {
    404: RunnerNotFoundError;
};
type ScanControllerPostTrackScansError = ScanControllerPostTrackScansErrors[keyof ScanControllerPostTrackScansErrors];
type ScanControllerPostTrackScansResponses = {
    200: ResponseTrackScan;
};
type ScanControllerPostTrackScansResponse = ScanControllerPostTrackScansResponses[keyof ScanControllerPostTrackScansResponses];
type ScanControllerPutTrackScanData = {
    /**
     * UpdateTrackScan
     */
    body?: UpdateTrackScan;
    path: {
        id: number;
    };
    query?: never;
    url: '/api/scans/trackscans/{id}';
};
type ScanControllerPutTrackScanErrors = {
    404: ScanNotFoundError | RunnerNotFoundError | ScanStationNotFoundError;
    406: ScanIdsNotMatchingError;
};
type ScanControllerPutTrackScanError = ScanControllerPutTrackScanErrors[keyof ScanControllerPutTrackScanErrors];
type ScanControllerPutTrackScanResponses = {
    200: ResponseTrackScan;
};
type ScanControllerPutTrackScanResponse = ScanControllerPutTrackScanResponses[keyof ScanControllerPutTrackScanResponses];
type RunnerCardControllerGetAllData = {
    body?: never;
    path?: never;
    query?: {
        page?: number;
        page_size?: number;
    };
    url: '/api/cards';
};
type RunnerCardControllerGetAllResponses = {
    200: Array<ResponseRunnerCard>;
};
type RunnerCardControllerGetAllResponse = RunnerCardControllerGetAllResponses[keyof RunnerCardControllerGetAllResponses];
type RunnerCardControllerPostData = {
    /**
     * CreateRunnerCard
     */
    body?: CreateRunnerCard;
    path?: never;
    query?: never;
    url: '/api/cards';
};
type RunnerCardControllerPostErrors = {
    404: RunnerNotFoundError;
};
type RunnerCardControllerPostError = RunnerCardControllerPostErrors[keyof RunnerCardControllerPostErrors];
type RunnerCardControllerPostResponses = {
    200: ResponseRunnerCard;
};
type RunnerCardControllerPostResponse = RunnerCardControllerPostResponses[keyof RunnerCardControllerPostResponses];
type RunnerCardControllerRemoveData = {
    body?: never;
    path: {
        id: number;
    };
    query?: {
        force?: boolean;
    };
    url: '/api/cards/{id}';
};
type RunnerCardControllerRemoveErrors = {
    406: RunnerCardHasScansError;
};
type RunnerCardControllerRemoveError = RunnerCardControllerRemoveErrors[keyof RunnerCardControllerRemoveErrors];
type RunnerCardControllerRemoveResponses = {
    200: ResponseRunnerCard;
    204: ResponseEmpty;
};
type RunnerCardControllerRemoveResponse = RunnerCardControllerRemoveResponses[keyof RunnerCardControllerRemoveResponses];
type RunnerCardControllerGetOneData = {
    body?: never;
    path: {
        id: number;
    };
    query?: never;
    url: '/api/cards/{id}';
};
type RunnerCardControllerGetOneErrors = {
    404: RunnerCardNotFoundError;
};
type RunnerCardControllerGetOneError = RunnerCardControllerGetOneErrors[keyof RunnerCardControllerGetOneErrors];
type RunnerCardControllerGetOneResponses = {
    200: ResponseRunnerCard;
};
type RunnerCardControllerGetOneResponse = RunnerCardControllerGetOneResponses[keyof RunnerCardControllerGetOneResponses];
type RunnerCardControllerPutData = {
    /**
     * UpdateRunnerCard
     */
    body?: UpdateRunnerCard;
    path: {
        id: number;
    };
    query?: never;
    url: '/api/cards/{id}';
};
type RunnerCardControllerPutErrors = {
    404: RunnerCardNotFoundError | RunnerNotFoundError;
    406: RunnerCardIdsNotMatchingError;
};
type RunnerCardControllerPutError = RunnerCardControllerPutErrors[keyof RunnerCardControllerPutErrors];
type RunnerCardControllerPutResponses = {
    200: ResponseRunnerCard;
};
type RunnerCardControllerPutResponse = RunnerCardControllerPutResponses[keyof RunnerCardControllerPutResponses];
type RunnerCardControllerPostBlancoBulkData = {
    body?: never;
    path?: never;
    query?: {
        count?: number;
        returnCards?: boolean;
    };
    url: '/api/cards/bulk';
};
type RunnerCardControllerPostBlancoBulkResponses = {
    200: ResponseEmpty;
};
type RunnerCardControllerPostBlancoBulkResponse = RunnerCardControllerPostBlancoBulkResponses[keyof RunnerCardControllerPostBlancoBulkResponses];
type RunnerControllerGetAllData = {
    body?: never;
    path?: never;
    query?: {
        page?: number;
        page_size?: number;
    };
    url: '/api/runners';
};
type RunnerControllerGetAllResponses = {
    200: Array<ResponseRunner>;
};
type RunnerControllerGetAllResponse = RunnerControllerGetAllResponses[keyof RunnerControllerGetAllResponses];
type RunnerControllerPostData = {
    /**
     * CreateRunner
     */
    body?: CreateRunner;
    path?: never;
    query?: never;
    url: '/api/runners';
};
type RunnerControllerPostResponses = {
    200: ResponseRunner | RunnerGroupNeededError | RunnerGroupNotFoundError;
};
type RunnerControllerPostResponse = RunnerControllerPostResponses[keyof RunnerControllerPostResponses];
type RunnerControllerRemoveData = {
    body?: never;
    path: {
        id: number;
    };
    query?: {
        force?: boolean;
    };
    url: '/api/runners/{id}';
};
type RunnerControllerRemoveErrors = {
    406: RunnerHasDistanceDonationsError;
};
type RunnerControllerRemoveError = RunnerControllerRemoveErrors[keyof RunnerControllerRemoveErrors];
type RunnerControllerRemoveResponses = {
    200: ResponseRunner;
    204: ResponseEmpty;
};
type RunnerControllerRemoveResponse = RunnerControllerRemoveResponses[keyof RunnerControllerRemoveResponses];
type RunnerControllerGetOneData = {
    body?: never;
    path: {
        id: number;
    };
    query?: never;
    url: '/api/runners/{id}';
};
type RunnerControllerGetOneErrors = {
    404: RunnerNotFoundError;
};
type RunnerControllerGetOneError = RunnerControllerGetOneErrors[keyof RunnerControllerGetOneErrors];
type RunnerControllerGetOneResponses = {
    200: ResponseRunner;
};
type RunnerControllerGetOneResponse = RunnerControllerGetOneResponses[keyof RunnerControllerGetOneResponses];
type RunnerControllerPutData = {
    /**
     * UpdateRunner
     */
    body?: UpdateRunner;
    path: {
        id: number;
    };
    query?: never;
    url: '/api/runners/{id}';
};
type RunnerControllerPutErrors = {
    404: RunnerNotFoundError;
    406: RunnerIdsNotMatchingError;
};
type RunnerControllerPutError = RunnerControllerPutErrors[keyof RunnerControllerPutErrors];
type RunnerControllerPutResponses = {
    200: ResponseRunner;
};
type RunnerControllerPutResponse = RunnerControllerPutResponses[keyof RunnerControllerPutResponses];
type RunnerControllerGetScansData = {
    body?: never;
    path: {
        id: number;
    };
    query?: never;
    url: '/api/runners/{id}/scans';
};
type RunnerControllerGetScansErrors = {
    404: RunnerNotFoundError;
};
type RunnerControllerGetScansError = RunnerControllerGetScansErrors[keyof RunnerControllerGetScansErrors];
type RunnerControllerGetScansResponses = {
    200: Array<ResponseScan> | Array<ResponseTrackScan>;
};
type RunnerControllerGetScansResponse = RunnerControllerGetScansResponses[keyof RunnerControllerGetScansResponses];
type ImportControllerPostJsonData = {
    /**
     * ImportRunner
     */
    body?: Array<ImportRunner>;
    path?: never;
    query?: {
        group?: number;
    };
    url: '/api/runners/import';
};
type ImportControllerPostJsonErrors = {
    404: RunnerGroupNotFoundError;
    406: RunnerGroupNeededError;
};
type ImportControllerPostJsonError = ImportControllerPostJsonErrors[keyof ImportControllerPostJsonErrors];
type ImportControllerPostJsonResponses = {
    200: Array<ResponseRunner>;
};
type ImportControllerPostJsonResponse = ImportControllerPostJsonResponses[keyof ImportControllerPostJsonResponses];
type ImportControllerPostOrgsJsonData = {
    /**
     * ImportRunner
     */
    body?: Array<ImportRunner>;
    path: {
        id: number;
    };
    query?: never;
    url: '/api/organizations/{id}/import';
};
type ImportControllerPostOrgsJsonErrors = {
    404: RunnerGroupNotFoundError;
    406: RunnerGroupNeededError;
};
type ImportControllerPostOrgsJsonError = ImportControllerPostOrgsJsonErrors[keyof ImportControllerPostOrgsJsonErrors];
type ImportControllerPostOrgsJsonResponses = {
    200: Array<ResponseRunner>;
};
type ImportControllerPostOrgsJsonResponse = ImportControllerPostOrgsJsonResponses[keyof ImportControllerPostOrgsJsonResponses];
type ImportControllerPostTeamsJsonData = {
    /**
     * ImportRunner
     */
    body?: Array<ImportRunner>;
    path: {
        id: number;
    };
    query?: never;
    url: '/api/teams/{id}/import';
};
type ImportControllerPostTeamsJsonErrors = {
    404: RunnerGroupNotFoundError;
    406: RunnerGroupNeededError;
};
type ImportControllerPostTeamsJsonError = ImportControllerPostTeamsJsonErrors[keyof ImportControllerPostTeamsJsonErrors];
type ImportControllerPostTeamsJsonResponses = {
    200: Array<ResponseRunner>;
};
type ImportControllerPostTeamsJsonResponse = ImportControllerPostTeamsJsonResponses[keyof ImportControllerPostTeamsJsonResponses];
type ImportControllerPostCsvData = {
    body?: never;
    path?: never;
    query?: {
        group?: number;
    };
    url: '/api/runners/import/csv';
};
type ImportControllerPostCsvErrors = {
    404: RunnerGroupNotFoundError;
    406: RunnerGroupNeededError;
};
type ImportControllerPostCsvError = ImportControllerPostCsvErrors[keyof ImportControllerPostCsvErrors];
type ImportControllerPostCsvResponses = {
    200: Array<ResponseRunner>;
};
type ImportControllerPostCsvResponse = ImportControllerPostCsvResponses[keyof ImportControllerPostCsvResponses];
type ImportControllerPostOrgsCsvData = {
    body?: never;
    path: {
        id: number;
    };
    query?: never;
    url: '/api/organizations/{id}/import/csv';
};
type ImportControllerPostOrgsCsvErrors = {
    404: RunnerGroupNotFoundError;
    406: RunnerGroupNeededError;
};
type ImportControllerPostOrgsCsvError = ImportControllerPostOrgsCsvErrors[keyof ImportControllerPostOrgsCsvErrors];
type ImportControllerPostOrgsCsvResponses = {
    200: Array<ResponseRunner>;
};
type ImportControllerPostOrgsCsvResponse = ImportControllerPostOrgsCsvResponses[keyof ImportControllerPostOrgsCsvResponses];
type ImportControllerPostTeamsCsvData = {
    body?: never;
    path: {
        id: number;
    };
    query?: never;
    url: '/api/teams/{id}/import/csv';
};
type ImportControllerPostTeamsCsvErrors = {
    404: RunnerGroupNotFoundError;
    406: RunnerGroupNeededError;
};
type ImportControllerPostTeamsCsvError = ImportControllerPostTeamsCsvErrors[keyof ImportControllerPostTeamsCsvErrors];
type ImportControllerPostTeamsCsvResponses = {
    200: Array<ResponseRunner>;
};
type ImportControllerPostTeamsCsvResponse = ImportControllerPostTeamsCsvResponses[keyof ImportControllerPostTeamsCsvResponses];
type PermissionControllerGetAllData = {
    body?: never;
    path?: never;
    query?: {
        page?: number;
        page_size?: number;
    };
    url: '/api/permissions';
};
type PermissionControllerGetAllResponses = {
    200: Array<ResponsePermission>;
};
type PermissionControllerGetAllResponse = PermissionControllerGetAllResponses[keyof PermissionControllerGetAllResponses];
type PermissionControllerPostData = {
    /**
     * CreatePermission
     */
    body?: CreatePermission;
    path?: never;
    query?: never;
    url: '/api/permissions';
};
type PermissionControllerPostErrors = {
    404: PrincipalNotFoundError;
};
type PermissionControllerPostError = PermissionControllerPostErrors[keyof PermissionControllerPostErrors];
type PermissionControllerPostResponses = {
    200: ResponsePermission;
};
type PermissionControllerPostResponse = PermissionControllerPostResponses[keyof PermissionControllerPostResponses];
type PermissionControllerRemoveData = {
    body?: never;
    path: {
        id: number;
    };
    query?: {
        force?: boolean;
    };
    url: '/api/permissions/{id}';
};
type PermissionControllerRemoveResponses = {
    200: ResponsePermission;
    204: ResponseEmpty;
};
type PermissionControllerRemoveResponse = PermissionControllerRemoveResponses[keyof PermissionControllerRemoveResponses];
type PermissionControllerGetOneData = {
    body?: never;
    path: {
        id: number;
    };
    query?: never;
    url: '/api/permissions/{id}';
};
type PermissionControllerGetOneErrors = {
    404: PermissionNotFoundError;
};
type PermissionControllerGetOneError = PermissionControllerGetOneErrors[keyof PermissionControllerGetOneErrors];
type PermissionControllerGetOneResponses = {
    200: ResponsePermission;
};
type PermissionControllerGetOneResponse = PermissionControllerGetOneResponses[keyof PermissionControllerGetOneResponses];
type PermissionControllerPutData = {
    /**
     * UpdatePermission
     */
    body?: UpdatePermission;
    path: {
        id: number;
    };
    query?: never;
    url: '/api/permissions/{id}';
};
type PermissionControllerPutErrors = {
    404: PermissionNotFoundError | PrincipalNotFoundError;
    406: PermissionIdsNotMatchingError | PermissionNeedsPrincipalError;
};
type PermissionControllerPutError = PermissionControllerPutErrors[keyof PermissionControllerPutErrors];
type PermissionControllerPutResponses = {
    200: ResponsePrincipal;
};
type PermissionControllerPutResponse = PermissionControllerPutResponses[keyof PermissionControllerPutResponses];
type MeControllerRemoveData = {
    body?: never;
    path?: never;
    query?: {
        force?: boolean;
    };
    url: '/api/users/me/';
};
type MeControllerRemoveErrors = {
    404: UserNotFoundError;
    406: UserDeletionNotConfirmedError;
};
type MeControllerRemoveError = MeControllerRemoveErrors[keyof MeControllerRemoveErrors];
type MeControllerRemoveResponses = {
    200: ResponseUser;
};
type MeControllerRemoveResponse = MeControllerRemoveResponses[keyof MeControllerRemoveResponses];
type MeControllerGetData = {
    body?: never;
    path?: never;
    query?: never;
    url: '/api/users/me/';
};
type MeControllerGetErrors = {
    404: UserNotFoundError;
};
type MeControllerGetError = MeControllerGetErrors[keyof MeControllerGetErrors];
type MeControllerGetResponses = {
    200: ResponseUser;
};
type MeControllerGetResponse = MeControllerGetResponses[keyof MeControllerGetResponses];
type MeControllerPutData = {
    /**
     * UpdateUser
     */
    body?: UpdateUser;
    path?: never;
    query?: never;
    url: '/api/users/me/';
};
type MeControllerPutErrors = {
    404: UserNotFoundError;
    406: UserIdsNotMatchingError | UsernameContainsIllegalCharacterError | PasswordMustContainUppercaseLetterError | PasswordMustContainLowercaseLetterError | PasswordMustContainNumberError | PasswordTooShortError;
};
type MeControllerPutError = MeControllerPutErrors[keyof MeControllerPutErrors];
type MeControllerPutResponses = {
    200: ResponseUser;
};
type MeControllerPutResponse = MeControllerPutResponses[keyof MeControllerPutResponses];
type MeControllerGetPermissionsData = {
    body?: never;
    path?: never;
    query?: never;
    url: '/api/users/me/permissions';
};
type MeControllerGetPermissionsErrors = {
    404: UserNotFoundError;
};
type MeControllerGetPermissionsError = MeControllerGetPermissionsErrors[keyof MeControllerGetPermissionsErrors];
type MeControllerGetPermissionsResponses = {
    200: ResponseUserPermissions;
};
type MeControllerGetPermissionsResponse = MeControllerGetPermissionsResponses[keyof MeControllerGetPermissionsResponses];
type RunnerTeamControllerGetAllData = {
    body?: never;
    path?: never;
    query?: {
        page?: number;
        page_size?: number;
    };
    url: '/api/teams';
};
type RunnerTeamControllerGetAllResponses = {
    200: Array<ResponseRunnerTeam>;
};
type RunnerTeamControllerGetAllResponse = RunnerTeamControllerGetAllResponses[keyof RunnerTeamControllerGetAllResponses];
type RunnerTeamControllerPostData = {
    /**
     * CreateRunnerTeam
     */
    body?: CreateRunnerTeam;
    path?: never;
    query?: never;
    url: '/api/teams';
};
type RunnerTeamControllerPostResponses = {
    200: ResponseRunnerTeam;
};
type RunnerTeamControllerPostResponse = RunnerTeamControllerPostResponses[keyof RunnerTeamControllerPostResponses];
type RunnerTeamControllerRemoveData = {
    body?: never;
    path: {
        id: number;
    };
    query?: {
        force?: boolean;
    };
    url: '/api/teams/{id}';
};
type RunnerTeamControllerRemoveErrors = {
    406: RunnerTeamHasRunnersError;
};
type RunnerTeamControllerRemoveError = RunnerTeamControllerRemoveErrors[keyof RunnerTeamControllerRemoveErrors];
type RunnerTeamControllerRemoveResponses = {
    200: ResponseRunnerTeam;
    204: ResponseEmpty;
};
type RunnerTeamControllerRemoveResponse = RunnerTeamControllerRemoveResponses[keyof RunnerTeamControllerRemoveResponses];
type RunnerTeamControllerGetOneData = {
    body?: never;
    path: {
        id: number;
    };
    query?: never;
    url: '/api/teams/{id}';
};
type RunnerTeamControllerGetOneErrors = {
    404: RunnerTeamNotFoundError;
};
type RunnerTeamControllerGetOneError = RunnerTeamControllerGetOneErrors[keyof RunnerTeamControllerGetOneErrors];
type RunnerTeamControllerGetOneResponses = {
    200: ResponseRunnerTeam;
};
type RunnerTeamControllerGetOneResponse = RunnerTeamControllerGetOneResponses[keyof RunnerTeamControllerGetOneResponses];
type RunnerTeamControllerPutData = {
    /**
     * UpdateRunnerTeam
     */
    body?: UpdateRunnerTeam;
    path: {
        id: number;
    };
    query?: never;
    url: '/api/teams/{id}';
};
type RunnerTeamControllerPutErrors = {
    404: RunnerTeamNotFoundError;
    406: RunnerTeamIdsNotMatchingError;
};
type RunnerTeamControllerPutError = RunnerTeamControllerPutErrors[keyof RunnerTeamControllerPutErrors];
type RunnerTeamControllerPutResponses = {
    200: ResponseRunnerTeam;
};
type RunnerTeamControllerPutResponse = RunnerTeamControllerPutResponses[keyof RunnerTeamControllerPutResponses];
type RunnerTeamControllerGetRunnersData = {
    body?: never;
    path: {
        id: number;
    };
    query?: never;
    url: '/api/teams/{id}/runners';
};
type RunnerTeamControllerGetRunnersErrors = {
    404: RunnerTeamNotFoundError;
};
type RunnerTeamControllerGetRunnersError = RunnerTeamControllerGetRunnersErrors[keyof RunnerTeamControllerGetRunnersErrors];
type RunnerTeamControllerGetRunnersResponses = {
    200: Array<ResponseRunner>;
};
type RunnerTeamControllerGetRunnersResponse = RunnerTeamControllerGetRunnersResponses[keyof RunnerTeamControllerGetRunnersResponses];
type RunnerOrganizationControllerGetAllData = {
    body?: never;
    path?: never;
    query?: {
        page?: number;
        page_size?: number;
    };
    url: '/api/organizations';
};
type RunnerOrganizationControllerGetAllResponses = {
    200: Array<ResponseRunnerOrganization>;
};
type RunnerOrganizationControllerGetAllResponse = RunnerOrganizationControllerGetAllResponses[keyof RunnerOrganizationControllerGetAllResponses];
type RunnerOrganizationControllerPostData = {
    /**
     * CreateRunnerOrganization
     */
    body?: CreateRunnerOrganization;
    path?: never;
    query?: never;
    url: '/api/organizations';
};
type RunnerOrganizationControllerPostResponses = {
    200: ResponseRunnerOrganization;
};
type RunnerOrganizationControllerPostResponse = RunnerOrganizationControllerPostResponses[keyof RunnerOrganizationControllerPostResponses];
type RunnerOrganizationControllerRemoveData = {
    body?: never;
    path: {
        id: number;
    };
    query?: {
        force?: boolean;
    };
    url: '/api/organizations/{id}';
};
type RunnerOrganizationControllerRemoveErrors = {
    406: RunnerOrganizationHasTeamsError | RunnerOrganizationHasRunnersError;
};
type RunnerOrganizationControllerRemoveError = RunnerOrganizationControllerRemoveErrors[keyof RunnerOrganizationControllerRemoveErrors];
type RunnerOrganizationControllerRemoveResponses = {
    200: ResponseRunnerOrganization;
    204: ResponseEmpty;
};
type RunnerOrganizationControllerRemoveResponse = RunnerOrganizationControllerRemoveResponses[keyof RunnerOrganizationControllerRemoveResponses];
type RunnerOrganizationControllerGetOneData = {
    body?: never;
    path: {
        id: number;
    };
    query?: never;
    url: '/api/organizations/{id}';
};
type RunnerOrganizationControllerGetOneErrors = {
    404: RunnerOrganizationNotFoundError;
};
type RunnerOrganizationControllerGetOneError = RunnerOrganizationControllerGetOneErrors[keyof RunnerOrganizationControllerGetOneErrors];
type RunnerOrganizationControllerGetOneResponses = {
    200: ResponseRunnerOrganization;
};
type RunnerOrganizationControllerGetOneResponse = RunnerOrganizationControllerGetOneResponses[keyof RunnerOrganizationControllerGetOneResponses];
type RunnerOrganizationControllerPutData = {
    /**
     * UpdateRunnerOrganization
     */
    body?: UpdateRunnerOrganization;
    path: {
        id: number;
    };
    query?: never;
    url: '/api/organizations/{id}';
};
type RunnerOrganizationControllerPutErrors = {
    404: RunnerOrganizationNotFoundError;
    406: RunnerOrganizationIdsNotMatchingError;
};
type RunnerOrganizationControllerPutError = RunnerOrganizationControllerPutErrors[keyof RunnerOrganizationControllerPutErrors];
type RunnerOrganizationControllerPutResponses = {
    200: ResponseRunnerOrganization;
};
type RunnerOrganizationControllerPutResponse = RunnerOrganizationControllerPutResponses[keyof RunnerOrganizationControllerPutResponses];
type RunnerOrganizationControllerGetRunnersData = {
    body?: never;
    path: {
        id: number;
    };
    query?: {
        onlyDirect?: boolean;
    };
    url: '/api/organizations/{id}/runners';
};
type RunnerOrganizationControllerGetRunnersErrors = {
    404: RunnerOrganizationNotFoundError;
};
type RunnerOrganizationControllerGetRunnersError = RunnerOrganizationControllerGetRunnersErrors[keyof RunnerOrganizationControllerGetRunnersErrors];
type RunnerOrganizationControllerGetRunnersResponses = {
    200: Array<ResponseRunner>;
};
type RunnerOrganizationControllerGetRunnersResponse = RunnerOrganizationControllerGetRunnersResponses[keyof RunnerOrganizationControllerGetRunnersResponses];
type RunnerSelfServiceControllerRemoveData = {
    body?: never;
    path: {
        jwt: string;
    };
    query?: {
        force?: boolean;
    };
    url: '/api/runners/me/{jwt}';
};
type RunnerSelfServiceControllerRemoveErrors = {
    404: RunnerNotFoundError;
};
type RunnerSelfServiceControllerRemoveError = RunnerSelfServiceControllerRemoveErrors[keyof RunnerSelfServiceControllerRemoveErrors];
type RunnerSelfServiceControllerRemoveResponses = {
    200: ResponseSelfServiceRunner;
};
type RunnerSelfServiceControllerRemoveResponse = RunnerSelfServiceControllerRemoveResponses[keyof RunnerSelfServiceControllerRemoveResponses];
type RunnerSelfServiceControllerGetData = {
    body?: never;
    path: {
        jwt: string;
    };
    query?: never;
    url: '/api/runners/me/{jwt}';
};
type RunnerSelfServiceControllerGetErrors = {
    404: RunnerNotFoundError;
};
type RunnerSelfServiceControllerGetError = RunnerSelfServiceControllerGetErrors[keyof RunnerSelfServiceControllerGetErrors];
type RunnerSelfServiceControllerGetResponses = {
    200: ResponseSelfServiceRunner;
};
type RunnerSelfServiceControllerGetResponse = RunnerSelfServiceControllerGetResponses[keyof RunnerSelfServiceControllerGetResponses];
type RunnerSelfServiceControllerGetScansData = {
    body?: never;
    path: {
        jwt: string;
    };
    query?: never;
    url: '/api/runners/me/{jwt}/scans';
};
type RunnerSelfServiceControllerGetScansErrors = {
    404: RunnerNotFoundError;
};
type RunnerSelfServiceControllerGetScansError = RunnerSelfServiceControllerGetScansErrors[keyof RunnerSelfServiceControllerGetScansErrors];
type RunnerSelfServiceControllerGetScansResponses = {
    200: Array<ResponseSelfServiceScan>;
};
type RunnerSelfServiceControllerGetScansResponse = RunnerSelfServiceControllerGetScansResponses[keyof RunnerSelfServiceControllerGetScansResponses];
type RunnerSelfServiceControllerGetStationMeData = {
    body?: never;
    path?: never;
    query?: never;
    url: '/api/stations/me';
};
type RunnerSelfServiceControllerGetStationMeErrors = {
    404: ScanStationNotFoundError;
};
type RunnerSelfServiceControllerGetStationMeError = RunnerSelfServiceControllerGetStationMeErrors[keyof RunnerSelfServiceControllerGetStationMeErrors];
type RunnerSelfServiceControllerGetStationMeResponses = {
    200: ResponseScanStation;
};
type RunnerSelfServiceControllerGetStationMeResponse = RunnerSelfServiceControllerGetStationMeResponses[keyof RunnerSelfServiceControllerGetStationMeResponses];
type RunnerSelfServiceControllerRequestNewTokenData = {
    body?: never;
    path?: never;
    query?: {
        mail?: string;
        locale?: string;
    };
    url: '/api/runners/login';
};
type RunnerSelfServiceControllerRequestNewTokenErrors = {
    404: RunnerNotFoundError;
};
type RunnerSelfServiceControllerRequestNewTokenError = RunnerSelfServiceControllerRequestNewTokenErrors[keyof RunnerSelfServiceControllerRequestNewTokenErrors];
type RunnerSelfServiceControllerRequestNewTokenResponses = {
    /**
     * Successful response
     */
    200: unknown;
};
type RunnerSelfServiceControllerRegisterRunnerData = {
    /**
     * CreateSelfServiceCitizenRunner
     */
    body?: CreateSelfServiceCitizenRunner;
    path?: never;
    query?: {
        locale?: string;
    };
    url: '/api/runners/register';
};
type RunnerSelfServiceControllerRegisterRunnerErrors = {
    406: RunnerEmailNeededError;
};
type RunnerSelfServiceControllerRegisterRunnerError = RunnerSelfServiceControllerRegisterRunnerErrors[keyof RunnerSelfServiceControllerRegisterRunnerErrors];
type RunnerSelfServiceControllerRegisterRunnerResponses = {
    200: ResponseSelfServiceRunner;
};
type RunnerSelfServiceControllerRegisterRunnerResponse = RunnerSelfServiceControllerRegisterRunnerResponses[keyof RunnerSelfServiceControllerRegisterRunnerResponses];
type RunnerSelfServiceControllerRegisterOrganizationRunnerData = {
    /**
     * CreateSelfServiceRunner
     */
    body?: CreateSelfServiceRunner;
    path: {
        token: string;
    };
    query?: {
        locale?: string;
    };
    url: '/api/runners/register/{token}';
};
type RunnerSelfServiceControllerRegisterOrganizationRunnerErrors = {
    404: RunnerOrganizationNotFoundError;
};
type RunnerSelfServiceControllerRegisterOrganizationRunnerError = RunnerSelfServiceControllerRegisterOrganizationRunnerErrors[keyof RunnerSelfServiceControllerRegisterOrganizationRunnerErrors];
type RunnerSelfServiceControllerRegisterOrganizationRunnerResponses = {
    200: ResponseSelfServiceRunner;
};
type RunnerSelfServiceControllerRegisterOrganizationRunnerResponse = RunnerSelfServiceControllerRegisterOrganizationRunnerResponses[keyof RunnerSelfServiceControllerRegisterOrganizationRunnerResponses];
type RunnerSelfServiceControllerGetSelfserviceOrgData = {
    body?: never;
    path: {
        token: string;
    };
    query?: never;
    url: '/api/organizations/selfservice/{token}';
};
type RunnerSelfServiceControllerGetSelfserviceOrgErrors = {
    404: RunnerOrganizationNotFoundError;
};
type RunnerSelfServiceControllerGetSelfserviceOrgError = RunnerSelfServiceControllerGetSelfserviceOrgErrors[keyof RunnerSelfServiceControllerGetSelfserviceOrgErrors];
type RunnerSelfServiceControllerGetSelfserviceOrgResponses = {
    200: ResponseSelfServiceOrganisation;
};
type RunnerSelfServiceControllerGetSelfserviceOrgResponse = RunnerSelfServiceControllerGetSelfserviceOrgResponses[keyof RunnerSelfServiceControllerGetSelfserviceOrgResponses];
type ScanStationControllerGetAllData = {
    body?: never;
    path?: never;
    query?: {
        page?: number;
        page_size?: number;
    };
    url: '/api/stations';
};
type ScanStationControllerGetAllResponses = {
    200: Array<ResponseScanStation>;
};
type ScanStationControllerGetAllResponse = ScanStationControllerGetAllResponses[keyof ScanStationControllerGetAllResponses];
type ScanStationControllerPostData = {
    /**
     * CreateScanStation
     */
    body?: CreateScanStation;
    path?: never;
    query?: never;
    url: '/api/stations';
};
type ScanStationControllerPostErrors = {
    404: TrackNotFoundError;
};
type ScanStationControllerPostError = ScanStationControllerPostErrors[keyof ScanStationControllerPostErrors];
type ScanStationControllerPostResponses = {
    200: ResponseScanStation;
};
type ScanStationControllerPostResponse = ScanStationControllerPostResponses[keyof ScanStationControllerPostResponses];
type ScanStationControllerRemoveData = {
    body?: never;
    path: {
        id: number;
    };
    query?: {
        force?: boolean;
    };
    url: '/api/stations/{id}';
};
type ScanStationControllerRemoveErrors = {
    406: ScanStationHasScansError;
};
type ScanStationControllerRemoveError = ScanStationControllerRemoveErrors[keyof ScanStationControllerRemoveErrors];
type ScanStationControllerRemoveResponses = {
    200: ResponseScanStation;
    204: ResponseEmpty;
};
type ScanStationControllerRemoveResponse = ScanStationControllerRemoveResponses[keyof ScanStationControllerRemoveResponses];
type ScanStationControllerGetOneData = {
    body?: never;
    path: {
        id: number;
    };
    query?: never;
    url: '/api/stations/{id}';
};
type ScanStationControllerGetOneErrors = {
    404: ScanStationNotFoundError;
};
type ScanStationControllerGetOneError = ScanStationControllerGetOneErrors[keyof ScanStationControllerGetOneErrors];
type ScanStationControllerGetOneResponses = {
    200: ResponseScanStation;
};
type ScanStationControllerGetOneResponse = ScanStationControllerGetOneResponses[keyof ScanStationControllerGetOneResponses];
type ScanStationControllerPutData = {
    /**
     * UpdateScanStation
     */
    body?: UpdateScanStation;
    path: {
        id: number;
    };
    query?: never;
    url: '/api/stations/{id}';
};
type ScanStationControllerPutErrors = {
    404: ScanStationNotFoundError;
    406: ScanStationIdsNotMatchingError;
};
type ScanStationControllerPutError = ScanStationControllerPutErrors[keyof ScanStationControllerPutErrors];
type ScanStationControllerPutResponses = {
    200: ResponseScanStation;
};
type ScanStationControllerPutResponse = ScanStationControllerPutResponses[keyof ScanStationControllerPutResponses];
type StatsClientControllerGetAllData = {
    body?: never;
    path?: never;
    query?: {
        page?: number;
        page_size?: number;
    };
    url: '/api/statsclients';
};
type StatsClientControllerGetAllResponses = {
    200: Array<ResponseStatsClient>;
};
type StatsClientControllerGetAllResponse = StatsClientControllerGetAllResponses[keyof StatsClientControllerGetAllResponses];
type StatsClientControllerPostData = {
    /**
     * CreateStatsClient
     */
    body?: CreateStatsClient;
    path?: never;
    query?: never;
    url: '/api/statsclients';
};
type StatsClientControllerPostResponses = {
    200: ResponseStatsClient;
};
type StatsClientControllerPostResponse = StatsClientControllerPostResponses[keyof StatsClientControllerPostResponses];
type StatsClientControllerRemoveData = {
    body?: never;
    path: {
        id: number;
    };
    query?: {
        force?: boolean;
    };
    url: '/api/statsclients/{id}';
};
type StatsClientControllerRemoveResponses = {
    200: ResponseStatsClient;
    204: ResponseEmpty;
};
type StatsClientControllerRemoveResponse = StatsClientControllerRemoveResponses[keyof StatsClientControllerRemoveResponses];
type StatsClientControllerGetOneData = {
    body?: never;
    path: {
        id: number;
    };
    query?: never;
    url: '/api/statsclients/{id}';
};
type StatsClientControllerGetOneErrors = {
    404: StatsClientNotFoundError;
};
type StatsClientControllerGetOneError = StatsClientControllerGetOneErrors[keyof StatsClientControllerGetOneErrors];
type StatsClientControllerGetOneResponses = {
    200: ResponseStatsClient;
};
type StatsClientControllerGetOneResponse = StatsClientControllerGetOneResponses[keyof StatsClientControllerGetOneResponses];
type StatsControllerGetData = {
    body?: never;
    path?: never;
    query?: never;
    url: '/api/stats';
};
type StatsControllerGetResponses = {
    200: ResponseStats;
};
type StatsControllerGetResponse = StatsControllerGetResponses[keyof StatsControllerGetResponses];
type StatsControllerGetTopRunnersByDistanceData = {
    body?: never;
    path?: never;
    query?: never;
    url: '/api/stats/runners/distance';
};
type StatsControllerGetTopRunnersByDistanceResponses = {
    200: Array<ResponseStatsRunner>;
};
type StatsControllerGetTopRunnersByDistanceResponse = StatsControllerGetTopRunnersByDistanceResponses[keyof StatsControllerGetTopRunnersByDistanceResponses];
type StatsControllerGetTopRunnersByDonationsData = {
    body?: never;
    path?: never;
    query?: never;
    url: '/api/stats/runners/donations';
};
type StatsControllerGetTopRunnersByDonationsResponses = {
    200: Array<ResponseStatsRunner>;
};
type StatsControllerGetTopRunnersByDonationsResponse = StatsControllerGetTopRunnersByDonationsResponses[keyof StatsControllerGetTopRunnersByDonationsResponses];
type StatsControllerGetTopRunnersByLaptimeData = {
    body?: never;
    path?: never;
    query?: {
        track?: number;
    };
    url: '/api/stats/runners/laptime';
};
type StatsControllerGetTopRunnersByLaptimeResponses = {
    200: Array<ResponseStatsRunner>;
};
type StatsControllerGetTopRunnersByLaptimeResponse = StatsControllerGetTopRunnersByLaptimeResponses[keyof StatsControllerGetTopRunnersByLaptimeResponses];
type StatsControllerGetTopRunnersByTrackTimeData = {
    body?: never;
    path?: never;
    query?: never;
    url: '/api/stats/scans';
};
type StatsControllerGetTopRunnersByTrackTimeResponses = {
    200: Array<ResponseStatsRunner>;
};
type StatsControllerGetTopRunnersByTrackTimeResponse = StatsControllerGetTopRunnersByTrackTimeResponses[keyof StatsControllerGetTopRunnersByTrackTimeResponses];
type StatsControllerGetTopTeamsByDistanceData = {
    body?: never;
    path?: never;
    query?: never;
    url: '/api/stats/teams/distance';
};
type StatsControllerGetTopTeamsByDistanceResponses = {
    200: Array<ResponseStatsTeam>;
};
type StatsControllerGetTopTeamsByDistanceResponse = StatsControllerGetTopTeamsByDistanceResponses[keyof StatsControllerGetTopTeamsByDistanceResponses];
type StatsControllerGetTopTeamsByDonationsData = {
    body?: never;
    path?: never;
    query?: never;
    url: '/api/stats/teams/donations';
};
type StatsControllerGetTopTeamsByDonationsResponses = {
    200: Array<ResponseStatsTeam>;
};
type StatsControllerGetTopTeamsByDonationsResponse = StatsControllerGetTopTeamsByDonationsResponses[keyof StatsControllerGetTopTeamsByDonationsResponses];
type StatsControllerGetTopOrgsByDistanceData = {
    body?: never;
    path?: never;
    query?: never;
    url: '/api/stats/organizations/distance';
};
type StatsControllerGetTopOrgsByDistanceResponses = {
    200: Array<ResponseStatsOrgnisation>;
};
type StatsControllerGetTopOrgsByDistanceResponse = StatsControllerGetTopOrgsByDistanceResponses[keyof StatsControllerGetTopOrgsByDistanceResponses];
type StatsControllerGetTopOrgsByDonationsData = {
    body?: never;
    path?: never;
    query?: never;
    url: '/api/stats/organizations/donations';
};
type StatsControllerGetTopOrgsByDonationsResponses = {
    200: Array<ResponseStatsOrgnisation>;
};
type StatsControllerGetTopOrgsByDonationsResponse = StatsControllerGetTopOrgsByDonationsResponses[keyof StatsControllerGetTopOrgsByDonationsResponses];
type StatusControllerGetData = {
    body?: never;
    path?: never;
    query?: never;
    url: '/api/status';
};
type StatusControllerGetResponses = {
    /**
     * Successful response
     */
    200: unknown;
};
type StatusControllerGetVersionData = {
    body?: never;
    path?: never;
    query?: never;
    url: '/api/version';
};
type StatusControllerGetVersionResponses = {
    /**
     * Successful response
     */
    200: unknown;
};
type TrackControllerGetAllData = {
    body?: never;
    path?: never;
    query?: {
        page?: number;
        page_size?: number;
    };
    url: '/api/tracks';
};
type TrackControllerGetAllResponses = {
    200: Array<ResponseTrack>;
};
type TrackControllerGetAllResponse = TrackControllerGetAllResponses[keyof TrackControllerGetAllResponses];
type TrackControllerPostData = {
    /**
     * CreateTrack
     */
    body?: CreateTrack;
    path?: never;
    query?: never;
    url: '/api/tracks';
};
type TrackControllerPostErrors = {
    406: TrackLapTimeCantBeNegativeError;
};
type TrackControllerPostError = TrackControllerPostErrors[keyof TrackControllerPostErrors];
type TrackControllerPostResponses = {
    200: ResponseTrack;
};
type TrackControllerPostResponse = TrackControllerPostResponses[keyof TrackControllerPostResponses];
type TrackControllerRemoveData = {
    body?: never;
    path: {
        id: number;
    };
    query?: {
        force?: boolean;
    };
    url: '/api/tracks/{id}';
};
type TrackControllerRemoveResponses = {
    200: ResponseTrack;
    204: ResponseEmpty;
};
type TrackControllerRemoveResponse = TrackControllerRemoveResponses[keyof TrackControllerRemoveResponses];
type TrackControllerGetOneData = {
    body?: never;
    path: {
        id: number;
    };
    query?: never;
    url: '/api/tracks/{id}';
};
type TrackControllerGetOneErrors = {
    404: TrackNotFoundError;
};
type TrackControllerGetOneError = TrackControllerGetOneErrors[keyof TrackControllerGetOneErrors];
type TrackControllerGetOneResponses = {
    200: ResponseTrack;
};
type TrackControllerGetOneResponse = TrackControllerGetOneResponses[keyof TrackControllerGetOneResponses];
type TrackControllerPutData = {
    /**
     * UpdateTrack
     */
    body?: UpdateTrack;
    path: {
        id: number;
    };
    query?: never;
    url: '/api/tracks/{id}';
};
type TrackControllerPutErrors = {
    404: TrackNotFoundError;
    406: TrackIdsNotMatchingError | TrackLapTimeCantBeNegativeError;
};
type TrackControllerPutError = TrackControllerPutErrors[keyof TrackControllerPutErrors];
type TrackControllerPutResponses = {
    200: ResponseTrack;
};
type TrackControllerPutResponse = TrackControllerPutResponses[keyof TrackControllerPutResponses];
type UserControllerGetAllData = {
    body?: never;
    path?: never;
    query?: {
        page?: number;
        page_size?: number;
    };
    url: '/api/users';
};
type UserControllerGetAllResponses = {
    200: Array<ResponseUser>;
};
type UserControllerGetAllResponse = UserControllerGetAllResponses[keyof UserControllerGetAllResponses];
type UserControllerPostData = {
    /**
     * CreateUser
     */
    body?: CreateUser;
    path?: never;
    query?: never;
    url: '/api/users';
};
type UserControllerPostErrors = {
    404: UserGroupNotFoundError;
    406: UsernameContainsIllegalCharacterError | PasswordMustContainUppercaseLetterError | PasswordMustContainLowercaseLetterError | PasswordMustContainNumberError | PasswordTooShortError;
};
type UserControllerPostError = UserControllerPostErrors[keyof UserControllerPostErrors];
type UserControllerPostResponses = {
    200: ResponseUser;
};
type UserControllerPostResponse = UserControllerPostResponses[keyof UserControllerPostResponses];
type UserControllerRemoveData = {
    body?: never;
    path: {
        id: number;
    };
    query?: {
        force?: boolean;
    };
    url: '/api/users/{id}';
};
type UserControllerRemoveErrors = {
    406: UserDeletionNotConfirmedError;
};
type UserControllerRemoveError = UserControllerRemoveErrors[keyof UserControllerRemoveErrors];
type UserControllerRemoveResponses = {
    200: ResponseUser;
    204: ResponseEmpty;
};
type UserControllerRemoveResponse = UserControllerRemoveResponses[keyof UserControllerRemoveResponses];
type UserControllerGetOneData = {
    body?: never;
    path: {
        id: number;
    };
    query?: never;
    url: '/api/users/{id}';
};
type UserControllerGetOneErrors = {
    404: UserNotFoundError;
};
type UserControllerGetOneError = UserControllerGetOneErrors[keyof UserControllerGetOneErrors];
type UserControllerGetOneResponses = {
    200: ResponseUser;
};
type UserControllerGetOneResponse = UserControllerGetOneResponses[keyof UserControllerGetOneResponses];
type UserControllerPutData = {
    /**
     * UpdateUser
     */
    body?: UpdateUser;
    path: {
        id: number;
    };
    query?: never;
    url: '/api/users/{id}';
};
type UserControllerPutErrors = {
    404: UserNotFoundError;
    406: UserIdsNotMatchingError | UsernameContainsIllegalCharacterError | PasswordMustContainUppercaseLetterError | PasswordMustContainLowercaseLetterError | PasswordMustContainNumberError | PasswordTooShortError;
};
type UserControllerPutError = UserControllerPutErrors[keyof UserControllerPutErrors];
type UserControllerPutResponses = {
    200: ResponseUser;
};
type UserControllerPutResponse = UserControllerPutResponses[keyof UserControllerPutResponses];
type UserControllerGetPermissionsData = {
    body?: never;
    path: {
        id: number;
    };
    query?: never;
    url: '/api/users/{id}/permissions';
};
type UserControllerGetPermissionsErrors = {
    404: UserNotFoundError;
};
type UserControllerGetPermissionsError = UserControllerGetPermissionsErrors[keyof UserControllerGetPermissionsErrors];
type UserControllerGetPermissionsResponses = {
    200: ResponseUser;
};
type UserControllerGetPermissionsResponse = UserControllerGetPermissionsResponses[keyof UserControllerGetPermissionsResponses];
type UserGroupControllerGetAllData = {
    body?: never;
    path?: never;
    query?: {
        page?: number;
        page_size?: number;
    };
    url: '/api/usergroups';
};
type UserGroupControllerGetAllResponses = {
    200: Array<ResponseUserGroup>;
};
type UserGroupControllerGetAllResponse = UserGroupControllerGetAllResponses[keyof UserGroupControllerGetAllResponses];
type UserGroupControllerPostData = {
    /**
     * CreateUserGroup
     */
    body?: CreateUserGroup;
    path?: never;
    query?: never;
    url: '/api/usergroups';
};
type UserGroupControllerPostResponses = {
    200: UserGroup | UserGroupNotFoundError;
};
type UserGroupControllerPostResponse = UserGroupControllerPostResponses[keyof UserGroupControllerPostResponses];
type UserGroupControllerRemoveData = {
    body?: never;
    path: {
        id: number;
    };
    query?: {
        force?: boolean;
    };
    url: '/api/usergroups/{id}';
};
type UserGroupControllerRemoveResponses = {
    200: ResponseUserGroup;
    204: ResponseEmpty;
};
type UserGroupControllerRemoveResponse = UserGroupControllerRemoveResponses[keyof UserGroupControllerRemoveResponses];
type UserGroupControllerGetOneData = {
    body?: never;
    path: {
        id: number;
    };
    query?: never;
    url: '/api/usergroups/{id}';
};
type UserGroupControllerGetOneErrors = {
    404: UserGroupNotFoundError;
};
type UserGroupControllerGetOneError = UserGroupControllerGetOneErrors[keyof UserGroupControllerGetOneErrors];
type UserGroupControllerGetOneResponses = {
    200: ResponseUserGroup;
};
type UserGroupControllerGetOneResponse = UserGroupControllerGetOneResponses[keyof UserGroupControllerGetOneResponses];
type UserGroupControllerPutData = {
    /**
     * UpdateUserGroup
     */
    body?: UpdateUserGroup;
    path: {
        id: number;
    };
    query?: never;
    url: '/api/usergroups/{id}';
};
type UserGroupControllerPutErrors = {
    404: UserGroupNotFoundError;
    406: UserGroupIdsNotMatchingError;
};
type UserGroupControllerPutError = UserGroupControllerPutErrors[keyof UserGroupControllerPutErrors];
type UserGroupControllerPutResponses = {
    200: UserGroup;
};
type UserGroupControllerPutResponse = UserGroupControllerPutResponses[keyof UserGroupControllerPutResponses];
type UserGroupControllerGetPermissionsData = {
    body?: never;
    path: {
        id: number;
    };
    query?: never;
    url: '/api/usergroups/{id}/permissions';
};
type UserGroupControllerGetPermissionsErrors = {
    404: UserGroupNotFoundError;
};
type UserGroupControllerGetPermissionsError = UserGroupControllerGetPermissionsErrors[keyof UserGroupControllerGetPermissionsErrors];
type UserGroupControllerGetPermissionsResponses = {
    200: ResponseUserGroupPermissions;
};
type UserGroupControllerGetPermissionsResponse = UserGroupControllerGetPermissionsResponses[keyof UserGroupControllerGetPermissionsResponses];
type ClientOptions = {
    baseUrl: 'https://run.lauf-fuer-kaya.de' | (string & {});
};

type Options<TData extends TDataShape = TDataShape, ThrowOnError extends boolean = boolean> = Options$1<TData, ThrowOnError> & {
    /**
     * You can provide a client instance returned by `createClient()` instead of
     * individual options. This might be also useful if you want to implement a
     * custom client.
     */
    client?: Client;
    /**
     * You can pass arbitrary values through the `meta` object. This can be
     * used to access values that aren't defined as part of the SDK function.
     */
    meta?: Record<string, unknown>;
};
/**
 * Login
 * Login with your username/email and password. <br> You will receive:
 * * access token (use it as a bearer token)
 * * refresh token (will also be sent as a cookie)
 */
declare const authControllerLogin: <ThrowOnError extends boolean = false>(options?: Options<AuthControllerLoginData, ThrowOnError>) => _hey_api_client_fetch.RequestResult<InvalidCredentialsError | UsernameOrEmailNeededError | PasswordNeededError | UserNotFoundError | ResponseAuth, unknown, ThrowOnError>;
/**
 * Logout
 * Logout using your refresh token. <br> This instantly invalidates all your access and refresh tokens.
 */
declare const authControllerLogout: <ThrowOnError extends boolean = false>(options?: Options<AuthControllerLogoutData, ThrowOnError>) => _hey_api_client_fetch.RequestResult<InvalidCredentialsError | UsernameOrEmailNeededError | PasswordNeededError | UserNotFoundError | Logout, unknown, ThrowOnError>;
/**
 * Refresh
 * Refresh your access and refresh tokens using a valid refresh token. <br> You will receive:
 * * access token (use it as a bearer token)
 * * refresh token (will also be sent as a cookie)
 */
declare const authControllerRefresh: <ThrowOnError extends boolean = false>(options?: Options<AuthControllerRefreshData, ThrowOnError>) => _hey_api_client_fetch.RequestResult<IllegalJwtError | UserNotFoundError | JwtNotProvidedError | RefreshTokenCountInvalidError | ResponseAuth, unknown, ThrowOnError>;
/**
 * Get reset token
 * Request a password reset token. <br> This will provide you with a reset token that you can use by posting to /api/auth/reset/{token}.
 */
declare const authControllerGetResetToken: <ThrowOnError extends boolean = false>(options?: Options<AuthControllerGetResetTokenData, ThrowOnError>) => _hey_api_client_fetch.RequestResult<ResponseEmpty, AuthControllerGetResetTokenError, ThrowOnError>;
/**
 * Reset password
 * Reset a user's utilising a valid password reset token. <br> This will set the user's password to the one you provided in the body. <br> To get a reset token post to /api/auth/reset with your username.
 */
declare const authControllerResetPassword: <ThrowOnError extends boolean = false>(options: Options<AuthControllerResetPasswordData, ThrowOnError>) => _hey_api_client_fetch.RequestResult<UsernameOrEmailNeededError | UserNotFoundError | ResponseAuth, unknown, ThrowOnError>;
/**
 * Get all
 * Lists all donations (fixed or distance based) from all donors. <br> This includes the donations's runner's distance ran(if distance donation).
 */
declare const donationControllerGetAll: <ThrowOnError extends boolean = false>(options?: Options<DonationControllerGetAllData, ThrowOnError>) => _hey_api_client_fetch.RequestResult<ResponseDonation[] | ResponseDistanceDonation[], unknown, ThrowOnError>;
/**
 * Remove
 * Delete the donation whose id you provided. <br> If no donation with this id exists it will just return 204(no content).
 */
declare const donationControllerRemove: <ThrowOnError extends boolean = false>(options: Options<DonationControllerRemoveData, ThrowOnError>) => _hey_api_client_fetch.RequestResult<DonationControllerRemoveResponse, unknown, ThrowOnError>;
/**
 * Get one
 * Lists all information about the donation whose id got provided. This includes the donation's runner's distance ran (if distance donation).
 */
declare const donationControllerGetOne: <ThrowOnError extends boolean = false>(options: Options<DonationControllerGetOneData, ThrowOnError>) => _hey_api_client_fetch.RequestResult<ResponseDonation | ResponseDistanceDonation, DonationNotFoundError, ThrowOnError>;
/**
 * Post fixed
 * Create a fixed donation (not distance donation - use /donations/distance instead). <br> Please rmemember to provide the donation's donors's id and amount.
 */
declare const donationControllerPostFixed: <ThrowOnError extends boolean = false>(options?: Options<DonationControllerPostFixedData, ThrowOnError>) => _hey_api_client_fetch.RequestResult<ResponseDonation, DonorNotFoundError, ThrowOnError>;
/**
 * Post distance
 * Create a distance donation (not fixed donation - use /donations/fixed instead). <br> Please rmemember to provide the donation's donors's and runners ids and amount per distance (kilometer).
 */
declare const donationControllerPostDistance: <ThrowOnError extends boolean = false>(options?: Options<DonationControllerPostDistanceData, ThrowOnError>) => _hey_api_client_fetch.RequestResult<ResponseDistanceDonation, DonorNotFoundError | RunnerNotFoundError, ThrowOnError>;
/**
 * Put fixed
 * Update the fixed donation (not distance donation - use /donations/distance instead) whose id you provided. <br> Please remember that ids can't be changed and amounts must be positive.
 */
declare const donationControllerPutFixed: <ThrowOnError extends boolean = false>(options: Options<DonationControllerPutFixedData, ThrowOnError>) => _hey_api_client_fetch.RequestResult<ResponseDonation, DonationControllerPutFixedError, ThrowOnError>;
/**
 * Put distance
 * Update the distance donation (not fixed donation - use /donations/fixed instead) whose id you provided. <br> Please remember that ids can't be changed and amountPerDistance must be positive.
 */
declare const donationControllerPutDistance: <ThrowOnError extends boolean = false>(options: Options<DonationControllerPutDistanceData, ThrowOnError>) => _hey_api_client_fetch.RequestResult<ResponseDonation, DonationControllerPutDistanceError, ThrowOnError>;
/**
 * Get all
 * Lists all donor. <br> This includes the donor's current donation amount.
 */
declare const donorControllerGetAll: <ThrowOnError extends boolean = false>(options?: Options<DonorControllerGetAllData, ThrowOnError>) => _hey_api_client_fetch.RequestResult<ResponseDonor[], unknown, ThrowOnError>;
/**
 * Post
 * Create a new donor.
 */
declare const donorControllerPost: <ThrowOnError extends boolean = false>(options?: Options<DonorControllerPostData, ThrowOnError>) => _hey_api_client_fetch.RequestResult<ResponseDonor, unknown, ThrowOnError>;
/**
 * Remove
 * Delete the donor whose id you provided. <br> If no donor with this id exists it will just return 204(no content). <br> If the donor still has donations associated this will fail, please provide the query param ?force=true to delete the donor with all associated donations.
 */
declare const donorControllerRemove: <ThrowOnError extends boolean = false>(options: Options<DonorControllerRemoveData, ThrowOnError>) => _hey_api_client_fetch.RequestResult<DonorControllerRemoveResponse, unknown, ThrowOnError>;
/**
 * Get one
 * Lists all information about the donor whose id got provided. <br> This includes the donor's current donation amount.
 */
declare const donorControllerGetOne: <ThrowOnError extends boolean = false>(options: Options<DonorControllerGetOneData, ThrowOnError>) => _hey_api_client_fetch.RequestResult<ResponseDonor, DonorNotFoundError, ThrowOnError>;
/**
 * Put
 * Update the donor whose id you provided. <br> Please remember that ids can't be changed.
 */
declare const donorControllerPut: <ThrowOnError extends boolean = false>(options: Options<DonorControllerPutData, ThrowOnError>) => _hey_api_client_fetch.RequestResult<ResponseDonor, DonorControllerPutError, ThrowOnError>;
/**
 * Get all
 * Lists all contacts. <br> This includes the contact's associated groups.
 */
declare const groupContactControllerGetAll: <ThrowOnError extends boolean = false>(options?: Options<GroupContactControllerGetAllData, ThrowOnError>) => _hey_api_client_fetch.RequestResult<ResponseGroupContact[], unknown, ThrowOnError>;
/**
 * Post
 * Create a new contact.
 */
declare const groupContactControllerPost: <ThrowOnError extends boolean = false>(options?: Options<GroupContactControllerPostData, ThrowOnError>) => _hey_api_client_fetch.RequestResult<ResponseGroupContact, RunnerGroupNotFoundError, ThrowOnError>;
/**
 * Remove
 * Delete the contact whose id you provided. <br> If no contact with this id exists it will just return 204(no content). <br> This won't delete any groups associated with the contact.
 */
declare const groupContactControllerRemove: <ThrowOnError extends boolean = false>(options: Options<GroupContactControllerRemoveData, ThrowOnError>) => _hey_api_client_fetch.RequestResult<GroupContactControllerRemoveResponse, unknown, ThrowOnError>;
/**
 * Get one
 * Lists all information about the contact whose id got provided. <br> This includes the contact's associated groups.
 */
declare const groupContactControllerGetOne: <ThrowOnError extends boolean = false>(options: Options<GroupContactControllerGetOneData, ThrowOnError>) => _hey_api_client_fetch.RequestResult<ResponseGroupContact, GroupContactNotFoundError, ThrowOnError>;
/**
 * Put
 * Update the contact whose id you provided. <br> Please remember that ids can't be changed.
 */
declare const groupContactControllerPut: <ThrowOnError extends boolean = false>(options: Options<GroupContactControllerPutData, ThrowOnError>) => _hey_api_client_fetch.RequestResult<ResponseGroupContact, GroupContactControllerPutError, ThrowOnError>;
/**
 * Get all
 * Lists all scans (normal or track) from all runners. <br> This includes the scan's runner's distance ran.
 */
declare const scanControllerGetAll: <ThrowOnError extends boolean = false>(options?: Options<ScanControllerGetAllData, ThrowOnError>) => _hey_api_client_fetch.RequestResult<ResponseScan[] | ResponseTrackScan[], unknown, ThrowOnError>;
/**
 * Post
 * Create a new scan (not track scan - use /scans/trackscans instead). <br> Please rmemember to provide the scan's runner's id and distance.
 */
declare const scanControllerPost: <ThrowOnError extends boolean = false>(options?: Options<ScanControllerPostData, ThrowOnError>) => _hey_api_client_fetch.RequestResult<ResponseScan, RunnerNotFoundError, ThrowOnError>;
/**
 * Remove
 * Delete the scan whose id you provided. <br> If no scan with this id exists it will just return 204(no content).
 */
declare const scanControllerRemove: <ThrowOnError extends boolean = false>(options: Options<ScanControllerRemoveData, ThrowOnError>) => _hey_api_client_fetch.RequestResult<ScanControllerRemoveResponse, unknown, ThrowOnError>;
/**
 * Get one
 * Lists all information about the scan whose id got provided. This includes the scan's runner's distance ran.
 */
declare const scanControllerGetOne: <ThrowOnError extends boolean = false>(options: Options<ScanControllerGetOneData, ThrowOnError>) => _hey_api_client_fetch.RequestResult<ResponseScan | ResponseTrackScan, ScanNotFoundError, ThrowOnError>;
/**
 * Put
 * Update the scan (not track scan use /scans/trackscans/:id instead) whose id you provided. <br> Please remember that ids can't be changed and distances must be positive.
 */
declare const scanControllerPut: <ThrowOnError extends boolean = false>(options: Options<ScanControllerPutData, ThrowOnError>) => _hey_api_client_fetch.RequestResult<ResponseScan, ScanControllerPutError, ThrowOnError>;
/**
 * Post track scans
 * Create a new track scan (for "normal" scans use /scans instead). <br> Please remember that to provide the scan's card's station's id.
 */
declare const scanControllerPostTrackScans: <ThrowOnError extends boolean = false>(options?: Options<ScanControllerPostTrackScansData, ThrowOnError>) => _hey_api_client_fetch.RequestResult<ResponseTrackScan, RunnerNotFoundError, ThrowOnError>;
/**
 * Put track scan
 * Update the track scan (not "normal" scan use /scans/trackscans/:id instead) whose id you provided. <br> Please remember that only the validity, runner and track can be changed.
 */
declare const scanControllerPutTrackScan: <ThrowOnError extends boolean = false>(options: Options<ScanControllerPutTrackScanData, ThrowOnError>) => _hey_api_client_fetch.RequestResult<ResponseTrackScan, ScanControllerPutTrackScanError, ThrowOnError>;
/**
 * Get all
 * Lists all card.
 */
declare const runnerCardControllerGetAll: <ThrowOnError extends boolean = false>(options?: Options<RunnerCardControllerGetAllData, ThrowOnError>) => _hey_api_client_fetch.RequestResult<ResponseRunnerCard[], unknown, ThrowOnError>;
/**
 * Post
 * Create a new card. <br> You can provide a associated runner by id but you don't have to.
 */
declare const runnerCardControllerPost: <ThrowOnError extends boolean = false>(options?: Options<RunnerCardControllerPostData, ThrowOnError>) => _hey_api_client_fetch.RequestResult<ResponseRunnerCard, RunnerNotFoundError, ThrowOnError>;
/**
 * Remove
 * Delete the card whose id you provided. <br> If no card with this id exists it will just return 204(no content). <br> If the card still has scans associated you have to provide the force=true query param (warning: this deletes all scans associated with by this card - please disable it instead or just remove the runner association).
 */
declare const runnerCardControllerRemove: <ThrowOnError extends boolean = false>(options: Options<RunnerCardControllerRemoveData, ThrowOnError>) => _hey_api_client_fetch.RequestResult<RunnerCardControllerRemoveResponse, RunnerCardHasScansError, ThrowOnError>;
/**
 * Get one
 * Lists all information about the card whose id got provided.
 */
declare const runnerCardControllerGetOne: <ThrowOnError extends boolean = false>(options: Options<RunnerCardControllerGetOneData, ThrowOnError>) => _hey_api_client_fetch.RequestResult<ResponseRunnerCard, RunnerCardNotFoundError, ThrowOnError>;
/**
 * Put
 * Update the card whose id you provided. <br> Scans created via this card will still be associated with the old runner. <br> Please remember that ids can't be changed.
 */
declare const runnerCardControllerPut: <ThrowOnError extends boolean = false>(options: Options<RunnerCardControllerPutData, ThrowOnError>) => _hey_api_client_fetch.RequestResult<ResponseRunnerCard, RunnerCardControllerPutError, ThrowOnError>;
/**
 * Post blanco bulk
 * Create blank cards in bulk. <br> Just provide the count as a query param and wait for the 200 response. <br> You can provide the 'returnCards' query param if you want to receive the RESPONSERUNNERCARD objects in the response.
 */
declare const runnerCardControllerPostBlancoBulk: <ThrowOnError extends boolean = false>(options?: Options<RunnerCardControllerPostBlancoBulkData, ThrowOnError>) => _hey_api_client_fetch.RequestResult<ResponseEmpty, unknown, ThrowOnError>;
/**
 * Get all
 * Lists all runners from all teams/orgs. <br> This includes the runner's group and distance ran.
 */
declare const runnerControllerGetAll: <ThrowOnError extends boolean = false>(options?: Options<RunnerControllerGetAllData, ThrowOnError>) => _hey_api_client_fetch.RequestResult<ResponseRunner[], unknown, ThrowOnError>;
/**
 * Post
 * Create a new runner. <br> Please remeber to provide the runner's group's id.
 */
declare const runnerControllerPost: <ThrowOnError extends boolean = false>(options?: Options<RunnerControllerPostData, ThrowOnError>) => _hey_api_client_fetch.RequestResult<ResponseRunner | RunnerGroupNotFoundError | RunnerGroupNeededError, unknown, ThrowOnError>;
/**
 * Remove
 * Delete the runner whose id you provided. <br> This will also delete all scans and cards associated with the runner. <br> If no runner with this id exists it will just return 204(no content).
 */
declare const runnerControllerRemove: <ThrowOnError extends boolean = false>(options: Options<RunnerControllerRemoveData, ThrowOnError>) => _hey_api_client_fetch.RequestResult<RunnerControllerRemoveResponse, RunnerHasDistanceDonationsError, ThrowOnError>;
/**
 * Get one
 * Lists all information about the runner whose id got provided.
 */
declare const runnerControllerGetOne: <ThrowOnError extends boolean = false>(options: Options<RunnerControllerGetOneData, ThrowOnError>) => _hey_api_client_fetch.RequestResult<ResponseRunner, RunnerNotFoundError, ThrowOnError>;
/**
 * Put
 * Update the runner whose id you provided. <br> Please remember that ids can't be changed.
 */
declare const runnerControllerPut: <ThrowOnError extends boolean = false>(options: Options<RunnerControllerPutData, ThrowOnError>) => _hey_api_client_fetch.RequestResult<ResponseRunner, RunnerControllerPutError, ThrowOnError>;
/**
 * Get scans
 * Lists all scans of the runner whose id got provided. <br> If you only want the valid scans just add the ?onlyValid=true query param.
 */
declare const runnerControllerGetScans: <ThrowOnError extends boolean = false>(options: Options<RunnerControllerGetScansData, ThrowOnError>) => _hey_api_client_fetch.RequestResult<ResponseScan[] | ResponseTrackScan[], RunnerNotFoundError, ThrowOnError>;
/**
 * Post json
 * Create new runners from json and insert them into the provided group. <br> If teams/classes are provided alongside the runner's name they'll automaticly be created under the provided org and the runners will be inserted into the teams instead.
 */
declare const importControllerPostJson: <ThrowOnError extends boolean = false>(options?: Options<ImportControllerPostJsonData, ThrowOnError>) => _hey_api_client_fetch.RequestResult<ResponseRunner[], ImportControllerPostJsonError, ThrowOnError>;
/**
 * Post orgs json
 * Create new runners from json and insert them into the provided org. <br> If teams/classes are provided alongside the runner's name they'll automaticly be created under the provided org and the runners will be inserted into the teams instead.
 */
declare const importControllerPostOrgsJson: <ThrowOnError extends boolean = false>(options: Options<ImportControllerPostOrgsJsonData, ThrowOnError>) => _hey_api_client_fetch.RequestResult<ResponseRunner[], ImportControllerPostOrgsJsonError, ThrowOnError>;
/**
 * Post teams json
 * Create new runners from json and insert them into the provided team
 */
declare const importControllerPostTeamsJson: <ThrowOnError extends boolean = false>(options: Options<ImportControllerPostTeamsJsonData, ThrowOnError>) => _hey_api_client_fetch.RequestResult<ResponseRunner[], ImportControllerPostTeamsJsonError, ThrowOnError>;
/**
 * Post csv
 * Create new runners from csv and insert them into the provided group. <br> If teams/classes are provided alongside the runner's name they'll automaticly be created under the provided org and the runners will be inserted into the teams instead.
 */
declare const importControllerPostCsv: <ThrowOnError extends boolean = false>(options?: Options<ImportControllerPostCsvData, ThrowOnError>) => _hey_api_client_fetch.RequestResult<ResponseRunner[], ImportControllerPostCsvError, ThrowOnError>;
/**
 * Post orgs csv
 * Create new runners from csv and insert them into the provided org. <br> If teams/classes are provided alongside the runner's name they'll automaticly be created under the provided org and the runners will be inserted into the teams instead.
 */
declare const importControllerPostOrgsCsv: <ThrowOnError extends boolean = false>(options: Options<ImportControllerPostOrgsCsvData, ThrowOnError>) => _hey_api_client_fetch.RequestResult<ResponseRunner[], ImportControllerPostOrgsCsvError, ThrowOnError>;
/**
 * Post teams csv
 * Create new runners from csv and insert them into the provided team
 */
declare const importControllerPostTeamsCsv: <ThrowOnError extends boolean = false>(options: Options<ImportControllerPostTeamsCsvData, ThrowOnError>) => _hey_api_client_fetch.RequestResult<ResponseRunner[], ImportControllerPostTeamsCsvError, ThrowOnError>;
/**
 * Get all
 * Lists all permissions for all users and groups.
 */
declare const permissionControllerGetAll: <ThrowOnError extends boolean = false>(options?: Options<PermissionControllerGetAllData, ThrowOnError>) => _hey_api_client_fetch.RequestResult<ResponsePermission[], unknown, ThrowOnError>;
/**
 * Post
 * Create a new permission for a existing principal(user/group). <br> If a permission with this target, action and prinicpal already exists that permission will be returned instead of creating a new one.
 */
declare const permissionControllerPost: <ThrowOnError extends boolean = false>(options?: Options<PermissionControllerPostData, ThrowOnError>) => _hey_api_client_fetch.RequestResult<ResponsePermission, PrincipalNotFoundError, ThrowOnError>;
/**
 * Remove
 * Deletes the permission whose id you provide. <br> If no permission with this id exists it will just return 204(no content).
 */
declare const permissionControllerRemove: <ThrowOnError extends boolean = false>(options: Options<PermissionControllerRemoveData, ThrowOnError>) => _hey_api_client_fetch.RequestResult<PermissionControllerRemoveResponse, unknown, ThrowOnError>;
/**
 * Get one
 * Lists all information about the permission whose id got provided.
 */
declare const permissionControllerGetOne: <ThrowOnError extends boolean = false>(options: Options<PermissionControllerGetOneData, ThrowOnError>) => _hey_api_client_fetch.RequestResult<ResponsePermission, PermissionNotFoundError, ThrowOnError>;
/**
 * Put
 * Update a permission object. <br> If updateing the permission object would result in duplicate permission (same target, action and principal) this permission will get deleted and the existing permission will be returned. <br> Please remember that ids can't be changed.
 */
declare const permissionControllerPut: <ThrowOnError extends boolean = false>(options: Options<PermissionControllerPutData, ThrowOnError>) => _hey_api_client_fetch.RequestResult<ResponsePrincipal, PermissionControllerPutError, ThrowOnError>;
/**
 * Remove
 * Delete yourself. <br> You have to confirm your decision by providing the ?force=true query param. <br> If there are any permissions directly granted to you they will get deleted as well.
 */
declare const meControllerRemove: <ThrowOnError extends boolean = false>(options?: Options<MeControllerRemoveData, ThrowOnError>) => _hey_api_client_fetch.RequestResult<ResponseUser, MeControllerRemoveError, ThrowOnError>;
/**
 * Get
 * Lists all information about yourself.
 */
declare const meControllerGet: <ThrowOnError extends boolean = false>(options?: Options<MeControllerGetData, ThrowOnError>) => _hey_api_client_fetch.RequestResult<ResponseUser, UserNotFoundError, ThrowOnError>;
/**
 * Put
 * Update the yourself. <br> You can't edit your own permissions or group memberships here - Please use the /api/users/:id enpoint instead. <br> Please remember that ids can't be changed.
 */
declare const meControllerPut: <ThrowOnError extends boolean = false>(options?: Options<MeControllerPutData, ThrowOnError>) => _hey_api_client_fetch.RequestResult<ResponseUser, MeControllerPutError, ThrowOnError>;
/**
 * Get permissions
 * Lists all permissions granted to the you sorted into directly granted and inherited as permission response objects.
 */
declare const meControllerGetPermissions: <ThrowOnError extends boolean = false>(options?: Options<MeControllerGetPermissionsData, ThrowOnError>) => _hey_api_client_fetch.RequestResult<ResponseUserPermissions, UserNotFoundError, ThrowOnError>;
/**
 * Get all
 * Lists all teams. <br> This includes their parent organization and contact (if existing/associated).
 */
declare const runnerTeamControllerGetAll: <ThrowOnError extends boolean = false>(options?: Options<RunnerTeamControllerGetAllData, ThrowOnError>) => _hey_api_client_fetch.RequestResult<ResponseRunnerTeam[], unknown, ThrowOnError>;
/**
 * Post
 * Create a new organsisation. <br> Please remember to provide it's parent group's id.
 */
declare const runnerTeamControllerPost: <ThrowOnError extends boolean = false>(options?: Options<RunnerTeamControllerPostData, ThrowOnError>) => _hey_api_client_fetch.RequestResult<ResponseRunnerTeam, unknown, ThrowOnError>;
/**
 * Remove
 * Delete the team whose id you provided. <br> If the team still has runners associated this will fail. <br> To delete the team with all associated runners set the force QueryParam to true (cascading deletion might take a while). <br> This won't delete the associated contact.<br> If no team with this id exists it will just return 204(no content).
 */
declare const runnerTeamControllerRemove: <ThrowOnError extends boolean = false>(options: Options<RunnerTeamControllerRemoveData, ThrowOnError>) => _hey_api_client_fetch.RequestResult<RunnerTeamControllerRemoveResponse, RunnerTeamHasRunnersError, ThrowOnError>;
/**
 * Get one
 * Lists all information about the team whose id got provided.
 */
declare const runnerTeamControllerGetOne: <ThrowOnError extends boolean = false>(options: Options<RunnerTeamControllerGetOneData, ThrowOnError>) => _hey_api_client_fetch.RequestResult<ResponseRunnerTeam, RunnerTeamNotFoundError, ThrowOnError>;
/**
 * Put
 * Update the team whose id you provided. <br> Please remember that ids can't be changed.
 */
declare const runnerTeamControllerPut: <ThrowOnError extends boolean = false>(options: Options<RunnerTeamControllerPutData, ThrowOnError>) => _hey_api_client_fetch.RequestResult<ResponseRunnerTeam, RunnerTeamControllerPutError, ThrowOnError>;
/**
 * Get runners
 * Lists all runners from this team. <br> This includes the runner's group and distance ran.
 */
declare const runnerTeamControllerGetRunners: <ThrowOnError extends boolean = false>(options: Options<RunnerTeamControllerGetRunnersData, ThrowOnError>) => _hey_api_client_fetch.RequestResult<ResponseRunner[], RunnerTeamNotFoundError, ThrowOnError>;
/**
 * Get all
 * Lists all organizations. <br> This includes their address, contact and teams (if existing/associated).
 */
declare const runnerOrganizationControllerGetAll: <ThrowOnError extends boolean = false>(options?: Options<RunnerOrganizationControllerGetAllData, ThrowOnError>) => _hey_api_client_fetch.RequestResult<ResponseRunnerOrganization[], unknown, ThrowOnError>;
/**
 * Post
 * Create a new organsisation.
 */
declare const runnerOrganizationControllerPost: <ThrowOnError extends boolean = false>(options?: Options<RunnerOrganizationControllerPostData, ThrowOnError>) => _hey_api_client_fetch.RequestResult<ResponseRunnerOrganization, unknown, ThrowOnError>;
/**
 * Remove
 * Delete the organsisation whose id you provided. <br> If the organization still has runners and/or teams associated this will fail. <br> To delete the organization with all associated runners and teams set the force QueryParam to true (cascading deletion might take a while). <br> This won't delete the associated contact. <br> If no organization with this id exists it will just return 204(no content).
 */
declare const runnerOrganizationControllerRemove: <ThrowOnError extends boolean = false>(options: Options<RunnerOrganizationControllerRemoveData, ThrowOnError>) => _hey_api_client_fetch.RequestResult<RunnerOrganizationControllerRemoveResponse, RunnerOrganizationHasRunnersError | RunnerOrganizationHasTeamsError, ThrowOnError>;
/**
 * Get one
 * Lists all information about the organization whose id got provided.
 */
declare const runnerOrganizationControllerGetOne: <ThrowOnError extends boolean = false>(options: Options<RunnerOrganizationControllerGetOneData, ThrowOnError>) => _hey_api_client_fetch.RequestResult<ResponseRunnerOrganization, RunnerOrganizationNotFoundError, ThrowOnError>;
/**
 * Put
 * Update the organization whose id you provided. <br> Please remember that ids can't be changed.
 */
declare const runnerOrganizationControllerPut: <ThrowOnError extends boolean = false>(options: Options<RunnerOrganizationControllerPutData, ThrowOnError>) => _hey_api_client_fetch.RequestResult<ResponseRunnerOrganization, RunnerOrganizationControllerPutError, ThrowOnError>;
/**
 * Get runners
 * Lists all runners from this org and it's teams (if you don't provide the ?onlyDirect=true param). <br> This includes the runner's group and distance ran.
 */
declare const runnerOrganizationControllerGetRunners: <ThrowOnError extends boolean = false>(options: Options<RunnerOrganizationControllerGetRunnersData, ThrowOnError>) => _hey_api_client_fetch.RequestResult<ResponseRunner[], RunnerOrganizationNotFoundError, ThrowOnError>;
/**
 * Remove
 * Deletes all information about yourself. <br> Please provide your runner jwt(that code we gave you during registration) for auth. <br> If you lost your jwt/personalized link please use the forgot endpoint.
 */
declare const runnerSelfServiceControllerRemove: <ThrowOnError extends boolean = false>(options: Options<RunnerSelfServiceControllerRemoveData, ThrowOnError>) => _hey_api_client_fetch.RequestResult<ResponseSelfServiceRunner, RunnerNotFoundError, ThrowOnError>;
/**
 * Get
 * Lists all information about yourself. <br> Please provide your runner jwt(that code we gave you during registration) for auth. <br> If you lost your jwt/personalized link please use the forgot endpoint.
 */
declare const runnerSelfServiceControllerGet: <ThrowOnError extends boolean = false>(options: Options<RunnerSelfServiceControllerGetData, ThrowOnError>) => _hey_api_client_fetch.RequestResult<ResponseSelfServiceRunner, RunnerNotFoundError, ThrowOnError>;
/**
 * Get scans
 * Lists all your (runner) scans. <br> Please provide your runner jwt(that code we gave you during registration) for auth. <br> If you lost your jwt/personalized link please contact support.
 */
declare const runnerSelfServiceControllerGetScans: <ThrowOnError extends boolean = false>(options: Options<RunnerSelfServiceControllerGetScansData, ThrowOnError>) => _hey_api_client_fetch.RequestResult<ResponseSelfServiceScan[], RunnerNotFoundError, ThrowOnError>;
/**
 * Get station me
 * Lists basic information about the station whose token got provided. <br> This includes it's associated track.
 */
declare const runnerSelfServiceControllerGetStationMe: <ThrowOnError extends boolean = false>(options?: Options<RunnerSelfServiceControllerGetStationMeData, ThrowOnError>) => _hey_api_client_fetch.RequestResult<ResponseScanStation, ScanStationNotFoundError, ThrowOnError>;
/**
 * Request new token
 * Use this endpoint to reuqest a new selfservice magic-login-link to be sent to your mail address (rate limited to one mail every 15mins).
 */
declare const runnerSelfServiceControllerRequestNewToken: <ThrowOnError extends boolean = false>(options?: Options<RunnerSelfServiceControllerRequestNewTokenData, ThrowOnError>) => _hey_api_client_fetch.RequestResult<unknown, RunnerNotFoundError, ThrowOnError>;
/**
 * Register runner
 * Create a new selfservice runner in the citizen org. <br> This endpoint shoud be used to allow "everyday citizen" to register themselves. <br> You have to provide a mail address, b/c the future we'll implement email verification.
 */
declare const runnerSelfServiceControllerRegisterRunner: <ThrowOnError extends boolean = false>(options?: Options<RunnerSelfServiceControllerRegisterRunnerData, ThrowOnError>) => _hey_api_client_fetch.RequestResult<ResponseSelfServiceRunner, RunnerEmailNeededError, ThrowOnError>;
/**
 * Register organization runner
 * Create a new selfservice runner in a provided org. <br> The orgs get provided and authorized via api tokens that can be optained via the /organizations endpoint.
 */
declare const runnerSelfServiceControllerRegisterOrganizationRunner: <ThrowOnError extends boolean = false>(options: Options<RunnerSelfServiceControllerRegisterOrganizationRunnerData, ThrowOnError>) => _hey_api_client_fetch.RequestResult<ResponseSelfServiceRunner, RunnerOrganizationNotFoundError, ThrowOnError>;
/**
 * Get selfservice org
 * Get the basic info and teams for a org.
 */
declare const runnerSelfServiceControllerGetSelfserviceOrg: <ThrowOnError extends boolean = false>(options: Options<RunnerSelfServiceControllerGetSelfserviceOrgData, ThrowOnError>) => _hey_api_client_fetch.RequestResult<ResponseSelfServiceOrganisation, RunnerOrganizationNotFoundError, ThrowOnError>;
/**
 * Get all
 * Lists all stations. <br> This includes their associated tracks.
 */
declare const scanStationControllerGetAll: <ThrowOnError extends boolean = false>(options?: Options<ScanStationControllerGetAllData, ThrowOnError>) => _hey_api_client_fetch.RequestResult<ResponseScanStation[], unknown, ThrowOnError>;
/**
 * Post
 * Create a new station. <br> Please remeber to provide the station's track's id. <br> Please also remember that the station key is only visibe on creation.
 */
declare const scanStationControllerPost: <ThrowOnError extends boolean = false>(options?: Options<ScanStationControllerPostData, ThrowOnError>) => _hey_api_client_fetch.RequestResult<ResponseScanStation, TrackNotFoundError, ThrowOnError>;
/**
 * Remove
 * Delete the station whose id you provided. <br> If no station with this id exists it will just return 204(no content). <br> If the station still has scans associated you have to provide the force=true query param (warning: this deletes all scans associated with/created by this station - please disable it instead).
 */
declare const scanStationControllerRemove: <ThrowOnError extends boolean = false>(options: Options<ScanStationControllerRemoveData, ThrowOnError>) => _hey_api_client_fetch.RequestResult<ScanStationControllerRemoveResponse, ScanStationHasScansError, ThrowOnError>;
/**
 * Get one
 * Lists all information about the station whose id got provided. <br> This includes it's associated track.
 */
declare const scanStationControllerGetOne: <ThrowOnError extends boolean = false>(options: Options<ScanStationControllerGetOneData, ThrowOnError>) => _hey_api_client_fetch.RequestResult<ResponseScanStation, ScanStationNotFoundError, ThrowOnError>;
/**
 * Put
 * Update the station whose id you provided. <br> Please remember that only the description and enabled state can be changed.
 */
declare const scanStationControllerPut: <ThrowOnError extends boolean = false>(options: Options<ScanStationControllerPutData, ThrowOnError>) => _hey_api_client_fetch.RequestResult<ResponseScanStation, ScanStationControllerPutError, ThrowOnError>;
/**
 * Get all
 * Lists all stats clients. Please remember that the key can only be viewed on creation.
 */
declare const statsClientControllerGetAll: <ThrowOnError extends boolean = false>(options?: Options<StatsClientControllerGetAllData, ThrowOnError>) => _hey_api_client_fetch.RequestResult<ResponseStatsClient[], unknown, ThrowOnError>;
/**
 * Post
 * Create a new stats client. <br> Please remember that the client's key will be generated automaticly and that it can only be viewed on creation.
 */
declare const statsClientControllerPost: <ThrowOnError extends boolean = false>(options?: Options<StatsClientControllerPostData, ThrowOnError>) => _hey_api_client_fetch.RequestResult<ResponseStatsClient, unknown, ThrowOnError>;
/**
 * Remove
 * Delete the stats client whose id you provided. <br> If no client with this id exists it will just return 204(no content).
 */
declare const statsClientControllerRemove: <ThrowOnError extends boolean = false>(options: Options<StatsClientControllerRemoveData, ThrowOnError>) => _hey_api_client_fetch.RequestResult<StatsClientControllerRemoveResponse, unknown, ThrowOnError>;
/**
 * Get one
 * Lists all information about the stats client whose id got provided. Please remember that the key can only be viewed on creation.
 */
declare const statsClientControllerGetOne: <ThrowOnError extends boolean = false>(options: Options<StatsClientControllerGetOneData, ThrowOnError>) => _hey_api_client_fetch.RequestResult<ResponseStatsClient, StatsClientNotFoundError, ThrowOnError>;
/**
 * Get
 * A very basic stats endpoint providing basic counters for a dashboard or simmilar
 */
declare const statsControllerGet: <ThrowOnError extends boolean = false>(options?: Options<StatsControllerGetData, ThrowOnError>) => _hey_api_client_fetch.RequestResult<ResponseStats, unknown, ThrowOnError>;
/**
 * Get top runners by distance
 * Returns the top ten runners by distance.
 */
declare const statsControllerGetTopRunnersByDistance: <ThrowOnError extends boolean = false>(options?: Options<StatsControllerGetTopRunnersByDistanceData, ThrowOnError>) => _hey_api_client_fetch.RequestResult<ResponseStatsRunner[], unknown, ThrowOnError>;
/**
 * Get top runners by donations
 * Returns the top ten runners by donations.
 */
declare const statsControllerGetTopRunnersByDonations: <ThrowOnError extends boolean = false>(options?: Options<StatsControllerGetTopRunnersByDonationsData, ThrowOnError>) => _hey_api_client_fetch.RequestResult<ResponseStatsRunner[], unknown, ThrowOnError>;
/**
 * Get top runners by laptime
 * Returns the top ten runners by fastest laptime on your selected track (track by id).
 */
declare const statsControllerGetTopRunnersByLaptime: <ThrowOnError extends boolean = false>(options?: Options<StatsControllerGetTopRunnersByLaptimeData, ThrowOnError>) => _hey_api_client_fetch.RequestResult<ResponseStatsRunner[], unknown, ThrowOnError>;
/**
 * Get top runners by track time
 * Returns the top ten fastest track times (with their runner and the runner's group).
 */
declare const statsControllerGetTopRunnersByTrackTime: <ThrowOnError extends boolean = false>(options?: Options<StatsControllerGetTopRunnersByTrackTimeData, ThrowOnError>) => _hey_api_client_fetch.RequestResult<ResponseStatsRunner[], unknown, ThrowOnError>;
/**
 * Get top teams by distance
 * Returns the top ten teams by distance.
 */
declare const statsControllerGetTopTeamsByDistance: <ThrowOnError extends boolean = false>(options?: Options<StatsControllerGetTopTeamsByDistanceData, ThrowOnError>) => _hey_api_client_fetch.RequestResult<ResponseStatsTeam[], unknown, ThrowOnError>;
/**
 * Get top teams by donations
 * Returns the top ten teams by donations.
 */
declare const statsControllerGetTopTeamsByDonations: <ThrowOnError extends boolean = false>(options?: Options<StatsControllerGetTopTeamsByDonationsData, ThrowOnError>) => _hey_api_client_fetch.RequestResult<ResponseStatsTeam[], unknown, ThrowOnError>;
/**
 * Get top orgs by distance
 * Returns the top ten organizations by distance.
 */
declare const statsControllerGetTopOrgsByDistance: <ThrowOnError extends boolean = false>(options?: Options<StatsControllerGetTopOrgsByDistanceData, ThrowOnError>) => _hey_api_client_fetch.RequestResult<ResponseStatsOrgnisation[], unknown, ThrowOnError>;
/**
 * Get top orgs by donations
 * Returns the top ten organizations by donations.
 */
declare const statsControllerGetTopOrgsByDonations: <ThrowOnError extends boolean = false>(options?: Options<StatsControllerGetTopOrgsByDonationsData, ThrowOnError>) => _hey_api_client_fetch.RequestResult<ResponseStatsOrgnisation[], unknown, ThrowOnError>;
/**
 * Get
 * A very basic status/health endpoint that just checks if the database connection is available. <br> The available information depth will be expanded later.
 */
declare const statusControllerGet: <ThrowOnError extends boolean = false>(options?: Options<StatusControllerGetData, ThrowOnError>) => _hey_api_client_fetch.RequestResult<unknown, unknown, ThrowOnError>;
/**
 * Get version
 * A very basic endpoint that just returns the curent package version.
 */
declare const statusControllerGetVersion: <ThrowOnError extends boolean = false>(options?: Options<StatusControllerGetVersionData, ThrowOnError>) => _hey_api_client_fetch.RequestResult<unknown, unknown, ThrowOnError>;
/**
 * Get all
 * Lists all tracks.
 */
declare const trackControllerGetAll: <ThrowOnError extends boolean = false>(options?: Options<TrackControllerGetAllData, ThrowOnError>) => _hey_api_client_fetch.RequestResult<ResponseTrack[], unknown, ThrowOnError>;
/**
 * Post
 * Create a new track. <br> Please remember that the track's distance must be greater than 0.
 */
declare const trackControllerPost: <ThrowOnError extends boolean = false>(options?: Options<TrackControllerPostData, ThrowOnError>) => _hey_api_client_fetch.RequestResult<ResponseTrack, TrackLapTimeCantBeNegativeError, ThrowOnError>;
/**
 * Remove
 * Delete the track whose id you provided. <br> If no track with this id exists it will just return 204(no content).
 */
declare const trackControllerRemove: <ThrowOnError extends boolean = false>(options: Options<TrackControllerRemoveData, ThrowOnError>) => _hey_api_client_fetch.RequestResult<TrackControllerRemoveResponse, unknown, ThrowOnError>;
/**
 * Get one
 * Lists all information about the track whose id got provided.
 */
declare const trackControllerGetOne: <ThrowOnError extends boolean = false>(options: Options<TrackControllerGetOneData, ThrowOnError>) => _hey_api_client_fetch.RequestResult<ResponseTrack, TrackNotFoundError, ThrowOnError>;
/**
 * Put
 * Update the track whose id you provided. <br> Please remember that ids can't be changed.
 */
declare const trackControllerPut: <ThrowOnError extends boolean = false>(options: Options<TrackControllerPutData, ThrowOnError>) => _hey_api_client_fetch.RequestResult<ResponseTrack, TrackControllerPutError, ThrowOnError>;
/**
 * Get all
 * Lists all users. <br> This includes their groups and permissions granted to them.
 */
declare const userControllerGetAll: <ThrowOnError extends boolean = false>(options?: Options<UserControllerGetAllData, ThrowOnError>) => _hey_api_client_fetch.RequestResult<ResponseUser[], unknown, ThrowOnError>;
/**
 * Post
 * Create a new user. <br> If you want to grant permissions to the user you have to create them seperately by posting to /api/permissions after creating the user.
 */
declare const userControllerPost: <ThrowOnError extends boolean = false>(options?: Options<UserControllerPostData, ThrowOnError>) => _hey_api_client_fetch.RequestResult<ResponseUser, UserControllerPostError, ThrowOnError>;
/**
 * Remove
 * Delete the user whose id you provided. <br> You have to confirm your decision by providing the ?force=true query param. <br> If there are any permissions directly granted to the user they will get deleted as well. <br> If no user with this id exists it will just return 204(no content).
 */
declare const userControllerRemove: <ThrowOnError extends boolean = false>(options: Options<UserControllerRemoveData, ThrowOnError>) => _hey_api_client_fetch.RequestResult<UserControllerRemoveResponse, UserDeletionNotConfirmedError, ThrowOnError>;
/**
 * Get one
 * Lists all information about the user whose id got provided. <br> Please remember that all permissions granted to the user will show up here.
 */
declare const userControllerGetOne: <ThrowOnError extends boolean = false>(options: Options<UserControllerGetOneData, ThrowOnError>) => _hey_api_client_fetch.RequestResult<ResponseUser, UserNotFoundError, ThrowOnError>;
/**
 * Put
 * Update the user whose id you provided. <br> To change the permissions directly granted to the user please use /api/permissions instead. <br> Please remember that ids can't be changed.
 */
declare const userControllerPut: <ThrowOnError extends boolean = false>(options: Options<UserControllerPutData, ThrowOnError>) => _hey_api_client_fetch.RequestResult<ResponseUser, UserControllerPutError, ThrowOnError>;
/**
 * Get permissions
 * Lists all permissions granted to the user sorted into directly granted and inherited as permission response objects.
 */
declare const userControllerGetPermissions: <ThrowOnError extends boolean = false>(options: Options<UserControllerGetPermissionsData, ThrowOnError>) => _hey_api_client_fetch.RequestResult<ResponseUser, UserNotFoundError, ThrowOnError>;
/**
 * Get all
 * Lists all groups. <br> The information provided might change while the project continues to evolve.
 */
declare const userGroupControllerGetAll: <ThrowOnError extends boolean = false>(options?: Options<UserGroupControllerGetAllData, ThrowOnError>) => _hey_api_client_fetch.RequestResult<ResponseUserGroup[], unknown, ThrowOnError>;
/**
 * Post
 * Create a new group. <br> If you want to grant permissions to the group you have to create them seperately by posting to /api/permissions after creating the group.
 */
declare const userGroupControllerPost: <ThrowOnError extends boolean = false>(options?: Options<UserGroupControllerPostData, ThrowOnError>) => _hey_api_client_fetch.RequestResult<UserGroup | UserGroupNotFoundError, unknown, ThrowOnError>;
/**
 * Remove
 * Delete the group whose id you provided. <br> If there are any permissions directly granted to the group they will get deleted as well. <br> Users associated with this group won't get deleted - just deassociated. <br> If no group with this id exists it will just return 204(no content).
 */
declare const userGroupControllerRemove: <ThrowOnError extends boolean = false>(options: Options<UserGroupControllerRemoveData, ThrowOnError>) => _hey_api_client_fetch.RequestResult<UserGroupControllerRemoveResponse, unknown, ThrowOnError>;
/**
 * Get one
 * Lists all information about the group whose id got provided. <br> The information provided might change while the project continues to evolve.
 */
declare const userGroupControllerGetOne: <ThrowOnError extends boolean = false>(options: Options<UserGroupControllerGetOneData, ThrowOnError>) => _hey_api_client_fetch.RequestResult<ResponseUserGroup, UserGroupNotFoundError, ThrowOnError>;
/**
 * Put
 * Update the group whose id you provided. <br> To change the permissions granted to the group please use /api/permissions instead. <br> Please remember that ids can't be changed.
 */
declare const userGroupControllerPut: <ThrowOnError extends boolean = false>(options: Options<UserGroupControllerPutData, ThrowOnError>) => _hey_api_client_fetch.RequestResult<UserGroup, UserGroupControllerPutError, ThrowOnError>;
/**
 * Get permissions
 * Lists all permissions granted to the group as permission response objects.
 */
declare const userGroupControllerGetPermissions: <ThrowOnError extends boolean = false>(options: Options<UserGroupControllerGetPermissionsData, ThrowOnError>) => _hey_api_client_fetch.RequestResult<ResponseUserGroupPermissions, UserGroupNotFoundError, ThrowOnError>;

export { type Address, type AddressCityEmptyError, type AddressCountryEmptyError, type AddressFirstLineEmptyError, type AddressPostalCodeEmptyError, type AddressPostalCodeInvalidError, type AuthControllerGetResetTokenData, type AuthControllerGetResetTokenError, type AuthControllerGetResetTokenErrors, type AuthControllerGetResetTokenResponse, type AuthControllerGetResetTokenResponses, type AuthControllerLoginData, type AuthControllerLoginResponse, type AuthControllerLoginResponses, type AuthControllerLogoutData, type AuthControllerLogoutResponse, type AuthControllerLogoutResponses, type AuthControllerRefreshData, type AuthControllerRefreshResponse, type AuthControllerRefreshResponses, type AuthControllerResetPasswordData, type AuthControllerResetPasswordResponse, type AuthControllerResetPasswordResponses, type ClientOptions, type ConfigFlag, type CreateAuth, type CreateDistanceDonation, type CreateDonation, type CreateDonor, type CreateFixedDonation, type CreateGroupContact, type CreateParticipant, type CreatePermission, type CreateResetToken, type CreateRunner, type CreateRunnerCard, type CreateRunnerGroup, type CreateRunnerOrganization, type CreateRunnerTeam, type CreateScan, type CreateScanStation, type CreateSelfServiceCitizenRunner, type CreateSelfServiceRunner, type CreateStatsClient, type CreateTrack, type CreateTrackScan, type CreateUser, type CreateUserGroup, type DistanceDonation, type Donation, type DonationControllerGetAllData, type DonationControllerGetAllResponse, type DonationControllerGetAllResponses, type DonationControllerGetOneData, type DonationControllerGetOneError, type DonationControllerGetOneErrors, type DonationControllerGetOneResponse, type DonationControllerGetOneResponses, type DonationControllerPostDistanceData, type DonationControllerPostDistanceError, type DonationControllerPostDistanceErrors, type DonationControllerPostDistanceResponse, type DonationControllerPostDistanceResponses, type DonationControllerPostFixedData, type DonationControllerPostFixedError, type DonationControllerPostFixedErrors, type DonationControllerPostFixedResponse, type DonationControllerPostFixedResponses, type DonationControllerPutDistanceData, type DonationControllerPutDistanceError, type DonationControllerPutDistanceErrors, type DonationControllerPutDistanceResponse, type DonationControllerPutDistanceResponses, type DonationControllerPutFixedData, type DonationControllerPutFixedError, type DonationControllerPutFixedErrors, type DonationControllerPutFixedResponse, type DonationControllerPutFixedResponses, type DonationControllerRemoveData, type DonationControllerRemoveResponse, type DonationControllerRemoveResponses, type DonationIdsNotMatchingError, type DonationNotFoundError, type Donor, type DonorControllerGetAllData, type DonorControllerGetAllResponse, type DonorControllerGetAllResponses, type DonorControllerGetOneData, type DonorControllerGetOneError, type DonorControllerGetOneErrors, type DonorControllerGetOneResponse, type DonorControllerGetOneResponses, type DonorControllerPostData, type DonorControllerPostResponse, type DonorControllerPostResponses, type DonorControllerPutData, type DonorControllerPutError, type DonorControllerPutErrors, type DonorControllerPutResponse, type DonorControllerPutResponses, type DonorControllerRemoveData, type DonorControllerRemoveResponse, type DonorControllerRemoveResponses, type DonorHasDonationsError, type DonorIdsNotMatchingError, type DonorNotFoundError, type DonorReceiptAddressNeededError, type FixedDonation, type GroupContact, type GroupContactControllerGetAllData, type GroupContactControllerGetAllResponse, type GroupContactControllerGetAllResponses, type GroupContactControllerGetOneData, type GroupContactControllerGetOneError, type GroupContactControllerGetOneErrors, type GroupContactControllerGetOneResponse, type GroupContactControllerGetOneResponses, type GroupContactControllerPostData, type GroupContactControllerPostError, type GroupContactControllerPostErrors, type GroupContactControllerPostResponse, type GroupContactControllerPostResponses, type GroupContactControllerPutData, type GroupContactControllerPutError, type GroupContactControllerPutErrors, type GroupContactControllerPutResponse, type GroupContactControllerPutResponses, type GroupContactControllerRemoveData, type GroupContactControllerRemoveResponse, type GroupContactControllerRemoveResponses, type GroupContactIdsNotMatchingError, type GroupContactNotFoundError, type GroupNameNeededError, type HandleLogout, type IllegalJwtError, type ImportControllerPostCsvData, type ImportControllerPostCsvError, type ImportControllerPostCsvErrors, type ImportControllerPostCsvResponse, type ImportControllerPostCsvResponses, type ImportControllerPostJsonData, type ImportControllerPostJsonError, type ImportControllerPostJsonErrors, type ImportControllerPostJsonResponse, type ImportControllerPostJsonResponses, type ImportControllerPostOrgsCsvData, type ImportControllerPostOrgsCsvError, type ImportControllerPostOrgsCsvErrors, type ImportControllerPostOrgsCsvResponse, type ImportControllerPostOrgsCsvResponses, type ImportControllerPostOrgsJsonData, type ImportControllerPostOrgsJsonError, type ImportControllerPostOrgsJsonErrors, type ImportControllerPostOrgsJsonResponse, type ImportControllerPostOrgsJsonResponses, type ImportControllerPostTeamsCsvData, type ImportControllerPostTeamsCsvError, type ImportControllerPostTeamsCsvErrors, type ImportControllerPostTeamsCsvResponse, type ImportControllerPostTeamsCsvResponses, type ImportControllerPostTeamsJsonData, type ImportControllerPostTeamsJsonError, type ImportControllerPostTeamsJsonErrors, type ImportControllerPostTeamsJsonResponse, type ImportControllerPostTeamsJsonResponses, type ImportRunner, type InvalidCredentialsError, type JwtNotProvidedError, type JwtUser, type Logout, type MailSendingError, type MeControllerGetData, type MeControllerGetError, type MeControllerGetErrors, type MeControllerGetPermissionsData, type MeControllerGetPermissionsError, type MeControllerGetPermissionsErrors, type MeControllerGetPermissionsResponse, type MeControllerGetPermissionsResponses, type MeControllerGetResponse, type MeControllerGetResponses, type MeControllerPutData, type MeControllerPutError, type MeControllerPutErrors, type MeControllerPutResponse, type MeControllerPutResponses, type MeControllerRemoveData, type MeControllerRemoveError, type MeControllerRemoveErrors, type MeControllerRemoveResponse, type MeControllerRemoveResponses, type NoPermissionError, type Options, type Participant, type PasswordMustContainLowercaseLetterError, type PasswordMustContainNumberError, type PasswordMustContainUppercaseLetterError, type PasswordNeededError, type PasswordTooShortError, type Permission, type PermissionControllerGetAllData, type PermissionControllerGetAllResponse, type PermissionControllerGetAllResponses, type PermissionControllerGetOneData, type PermissionControllerGetOneError, type PermissionControllerGetOneErrors, type PermissionControllerGetOneResponse, type PermissionControllerGetOneResponses, type PermissionControllerPostData, type PermissionControllerPostError, type PermissionControllerPostErrors, type PermissionControllerPostResponse, type PermissionControllerPostResponses, type PermissionControllerPutData, type PermissionControllerPutError, type PermissionControllerPutErrors, type PermissionControllerPutResponse, type PermissionControllerPutResponses, type PermissionControllerRemoveData, type PermissionControllerRemoveResponse, type PermissionControllerRemoveResponses, type PermissionIdsNotMatchingError, type PermissionNeedsPrincipalError, type PermissionNotFoundError, type Principal, type PrincipalNotFoundError, type PrincipalWrongTypeError, type RefreshAuth, type RefreshTokenCountInvalidError, type ResetAlreadyRequestedError, type ResetPassword, type ResponseAuth, type ResponseDistanceDonation, type ResponseDonation, type ResponseDonor, type ResponseEmpty, type ResponseGroupContact, type ResponseParticipant, type ResponsePermission, type ResponsePrincipal, type ResponseRunner, type ResponseRunnerCard, type ResponseRunnerGroup, type ResponseRunnerOrganization, type ResponseRunnerTeam, type ResponseScan, type ResponseScanStation, type ResponseSelfServiceDonation, type ResponseSelfServiceDonor, type ResponseSelfServiceOrganisation, type ResponseSelfServiceRunner, type ResponseSelfServiceScan, type ResponseSelfServiceTeam, type ResponseStats, type ResponseStatsClient, type ResponseStatsOrgnisation, type ResponseStatsRunner, type ResponseStatsTeam, type ResponseTrack, type ResponseTrackScan, type ResponseUser, type ResponseUserGroup, type ResponseUserGroupPermissions, type ResponseUserPermissions, type Runner, type RunnerCard, type RunnerCardControllerGetAllData, type RunnerCardControllerGetAllResponse, type RunnerCardControllerGetAllResponses, type RunnerCardControllerGetOneData, type RunnerCardControllerGetOneError, type RunnerCardControllerGetOneErrors, type RunnerCardControllerGetOneResponse, type RunnerCardControllerGetOneResponses, type RunnerCardControllerPostBlancoBulkData, type RunnerCardControllerPostBlancoBulkResponse, type RunnerCardControllerPostBlancoBulkResponses, type RunnerCardControllerPostData, type RunnerCardControllerPostError, type RunnerCardControllerPostErrors, type RunnerCardControllerPostResponse, type RunnerCardControllerPostResponses, type RunnerCardControllerPutData, type RunnerCardControllerPutError, type RunnerCardControllerPutErrors, type RunnerCardControllerPutResponse, type RunnerCardControllerPutResponses, type RunnerCardControllerRemoveData, type RunnerCardControllerRemoveError, type RunnerCardControllerRemoveErrors, type RunnerCardControllerRemoveResponse, type RunnerCardControllerRemoveResponses, type RunnerCardHasScansError, type RunnerCardIdOutOfRangeError, type RunnerCardIdsNotMatchingError, type RunnerCardNotFoundError, type RunnerControllerGetAllData, type RunnerControllerGetAllResponse, type RunnerControllerGetAllResponses, type RunnerControllerGetOneData, type RunnerControllerGetOneError, type RunnerControllerGetOneErrors, type RunnerControllerGetOneResponse, type RunnerControllerGetOneResponses, type RunnerControllerGetScansData, type RunnerControllerGetScansError, type RunnerControllerGetScansErrors, type RunnerControllerGetScansResponse, type RunnerControllerGetScansResponses, type RunnerControllerPostData, type RunnerControllerPostResponse, type RunnerControllerPostResponses, type RunnerControllerPutData, type RunnerControllerPutError, type RunnerControllerPutErrors, type RunnerControllerPutResponse, type RunnerControllerPutResponses, type RunnerControllerRemoveData, type RunnerControllerRemoveError, type RunnerControllerRemoveErrors, type RunnerControllerRemoveResponse, type RunnerControllerRemoveResponses, type RunnerEmailNeededError, type RunnerGroup, type RunnerGroupNeededError, type RunnerGroupNotFoundError, type RunnerHasDistanceDonationsError, type RunnerIdsNotMatchingError, type RunnerNotFoundError, type RunnerOrganization, type RunnerOrganizationControllerGetAllData, type RunnerOrganizationControllerGetAllResponse, type RunnerOrganizationControllerGetAllResponses, type RunnerOrganizationControllerGetOneData, type RunnerOrganizationControllerGetOneError, type RunnerOrganizationControllerGetOneErrors, type RunnerOrganizationControllerGetOneResponse, type RunnerOrganizationControllerGetOneResponses, type RunnerOrganizationControllerGetRunnersData, type RunnerOrganizationControllerGetRunnersError, type RunnerOrganizationControllerGetRunnersErrors, type RunnerOrganizationControllerGetRunnersResponse, type RunnerOrganizationControllerGetRunnersResponses, type RunnerOrganizationControllerPostData, type RunnerOrganizationControllerPostResponse, type RunnerOrganizationControllerPostResponses, type RunnerOrganizationControllerPutData, type RunnerOrganizationControllerPutError, type RunnerOrganizationControllerPutErrors, type RunnerOrganizationControllerPutResponse, type RunnerOrganizationControllerPutResponses, type RunnerOrganizationControllerRemoveData, type RunnerOrganizationControllerRemoveError, type RunnerOrganizationControllerRemoveErrors, type RunnerOrganizationControllerRemoveResponse, type RunnerOrganizationControllerRemoveResponses, type RunnerOrganizationHasRunnersError, type RunnerOrganizationHasTeamsError, type RunnerOrganizationIdsNotMatchingError, type RunnerOrganizationNotFoundError, type RunnerOrganizationWrongTypeError, type RunnerSelfServiceControllerGetData, type RunnerSelfServiceControllerGetError, type RunnerSelfServiceControllerGetErrors, type RunnerSelfServiceControllerGetResponse, type RunnerSelfServiceControllerGetResponses, type RunnerSelfServiceControllerGetScansData, type RunnerSelfServiceControllerGetScansError, type RunnerSelfServiceControllerGetScansErrors, type RunnerSelfServiceControllerGetScansResponse, type RunnerSelfServiceControllerGetScansResponses, type RunnerSelfServiceControllerGetSelfserviceOrgData, type RunnerSelfServiceControllerGetSelfserviceOrgError, type RunnerSelfServiceControllerGetSelfserviceOrgErrors, type RunnerSelfServiceControllerGetSelfserviceOrgResponse, type RunnerSelfServiceControllerGetSelfserviceOrgResponses, type RunnerSelfServiceControllerGetStationMeData, type RunnerSelfServiceControllerGetStationMeError, type RunnerSelfServiceControllerGetStationMeErrors, type RunnerSelfServiceControllerGetStationMeResponse, type RunnerSelfServiceControllerGetStationMeResponses, type RunnerSelfServiceControllerRegisterOrganizationRunnerData, type RunnerSelfServiceControllerRegisterOrganizationRunnerError, type RunnerSelfServiceControllerRegisterOrganizationRunnerErrors, type RunnerSelfServiceControllerRegisterOrganizationRunnerResponse, type RunnerSelfServiceControllerRegisterOrganizationRunnerResponses, type RunnerSelfServiceControllerRegisterRunnerData, type RunnerSelfServiceControllerRegisterRunnerError, type RunnerSelfServiceControllerRegisterRunnerErrors, type RunnerSelfServiceControllerRegisterRunnerResponse, type RunnerSelfServiceControllerRegisterRunnerResponses, type RunnerSelfServiceControllerRemoveData, type RunnerSelfServiceControllerRemoveError, type RunnerSelfServiceControllerRemoveErrors, type RunnerSelfServiceControllerRemoveResponse, type RunnerSelfServiceControllerRemoveResponses, type RunnerSelfServiceControllerRequestNewTokenData, type RunnerSelfServiceControllerRequestNewTokenError, type RunnerSelfServiceControllerRequestNewTokenErrors, type RunnerSelfServiceControllerRequestNewTokenResponses, type RunnerSelfserviceTimeoutError, type RunnerTeam, type RunnerTeamControllerGetAllData, type RunnerTeamControllerGetAllResponse, type RunnerTeamControllerGetAllResponses, type RunnerTeamControllerGetOneData, type RunnerTeamControllerGetOneError, type RunnerTeamControllerGetOneErrors, type RunnerTeamControllerGetOneResponse, type RunnerTeamControllerGetOneResponses, type RunnerTeamControllerGetRunnersData, type RunnerTeamControllerGetRunnersError, type RunnerTeamControllerGetRunnersErrors, type RunnerTeamControllerGetRunnersResponse, type RunnerTeamControllerGetRunnersResponses, type RunnerTeamControllerPostData, type RunnerTeamControllerPostResponse, type RunnerTeamControllerPostResponses, type RunnerTeamControllerPutData, type RunnerTeamControllerPutError, type RunnerTeamControllerPutErrors, type RunnerTeamControllerPutResponse, type RunnerTeamControllerPutResponses, type RunnerTeamControllerRemoveData, type RunnerTeamControllerRemoveError, type RunnerTeamControllerRemoveErrors, type RunnerTeamControllerRemoveResponse, type RunnerTeamControllerRemoveResponses, type RunnerTeamHasRunnersError, type RunnerTeamIdsNotMatchingError, type RunnerTeamNeedsParentError, type RunnerTeamNotFoundError, type Scan, type ScanControllerGetAllData, type ScanControllerGetAllResponse, type ScanControllerGetAllResponses, type ScanControllerGetOneData, type ScanControllerGetOneError, type ScanControllerGetOneErrors, type ScanControllerGetOneResponse, type ScanControllerGetOneResponses, type ScanControllerPostData, type ScanControllerPostError, type ScanControllerPostErrors, type ScanControllerPostResponse, type ScanControllerPostResponses, type ScanControllerPostTrackScansData, type ScanControllerPostTrackScansError, type ScanControllerPostTrackScansErrors, type ScanControllerPostTrackScansResponse, type ScanControllerPostTrackScansResponses, type ScanControllerPutData, type ScanControllerPutError, type ScanControllerPutErrors, type ScanControllerPutResponse, type ScanControllerPutResponses, type ScanControllerPutTrackScanData, type ScanControllerPutTrackScanError, type ScanControllerPutTrackScanErrors, type ScanControllerPutTrackScanResponse, type ScanControllerPutTrackScanResponses, type ScanControllerRemoveData, type ScanControllerRemoveResponse, type ScanControllerRemoveResponses, type ScanIdsNotMatchingError, type ScanNotFoundError, type ScanStation, type ScanStationControllerGetAllData, type ScanStationControllerGetAllResponse, type ScanStationControllerGetAllResponses, type ScanStationControllerGetOneData, type ScanStationControllerGetOneError, type ScanStationControllerGetOneErrors, type ScanStationControllerGetOneResponse, type ScanStationControllerGetOneResponses, type ScanStationControllerPostData, type ScanStationControllerPostError, type ScanStationControllerPostErrors, type ScanStationControllerPostResponse, type ScanStationControllerPostResponses, type ScanStationControllerPutData, type ScanStationControllerPutError, type ScanStationControllerPutErrors, type ScanStationControllerPutResponse, type ScanStationControllerPutResponses, type ScanStationControllerRemoveData, type ScanStationControllerRemoveError, type ScanStationControllerRemoveErrors, type ScanStationControllerRemoveResponse, type ScanStationControllerRemoveResponses, type ScanStationHasScansError, type ScanStationIdsNotMatchingError, type ScanStationNotFoundError, type StatsClient, type StatsClientControllerGetAllData, type StatsClientControllerGetAllResponse, type StatsClientControllerGetAllResponses, type StatsClientControllerGetOneData, type StatsClientControllerGetOneError, type StatsClientControllerGetOneErrors, type StatsClientControllerGetOneResponse, type StatsClientControllerGetOneResponses, type StatsClientControllerPostData, type StatsClientControllerPostResponse, type StatsClientControllerPostResponses, type StatsClientControllerRemoveData, type StatsClientControllerRemoveResponse, type StatsClientControllerRemoveResponses, type StatsClientIdsNotMatchingError, type StatsClientNotFoundError, type StatsControllerGetData, type StatsControllerGetResponse, type StatsControllerGetResponses, type StatsControllerGetTopOrgsByDistanceData, type StatsControllerGetTopOrgsByDistanceResponse, type StatsControllerGetTopOrgsByDistanceResponses, type StatsControllerGetTopOrgsByDonationsData, type StatsControllerGetTopOrgsByDonationsResponse, type StatsControllerGetTopOrgsByDonationsResponses, type StatsControllerGetTopRunnersByDistanceData, type StatsControllerGetTopRunnersByDistanceResponse, type StatsControllerGetTopRunnersByDistanceResponses, type StatsControllerGetTopRunnersByDonationsData, type StatsControllerGetTopRunnersByDonationsResponse, type StatsControllerGetTopRunnersByDonationsResponses, type StatsControllerGetTopRunnersByLaptimeData, type StatsControllerGetTopRunnersByLaptimeResponse, type StatsControllerGetTopRunnersByLaptimeResponses, type StatsControllerGetTopRunnersByTrackTimeData, type StatsControllerGetTopRunnersByTrackTimeResponse, type StatsControllerGetTopRunnersByTrackTimeResponses, type StatsControllerGetTopTeamsByDistanceData, type StatsControllerGetTopTeamsByDistanceResponse, type StatsControllerGetTopTeamsByDistanceResponses, type StatsControllerGetTopTeamsByDonationsData, type StatsControllerGetTopTeamsByDonationsResponse, type StatsControllerGetTopTeamsByDonationsResponses, type StatusControllerGetData, type StatusControllerGetResponses, type StatusControllerGetVersionData, type StatusControllerGetVersionResponses, type Track, type TrackControllerGetAllData, type TrackControllerGetAllResponse, type TrackControllerGetAllResponses, type TrackControllerGetOneData, type TrackControllerGetOneError, type TrackControllerGetOneErrors, type TrackControllerGetOneResponse, type TrackControllerGetOneResponses, type TrackControllerPostData, type TrackControllerPostError, type TrackControllerPostErrors, type TrackControllerPostResponse, type TrackControllerPostResponses, type TrackControllerPutData, type TrackControllerPutError, type TrackControllerPutErrors, type TrackControllerPutResponse, type TrackControllerPutResponses, type TrackControllerRemoveData, type TrackControllerRemoveResponse, type TrackControllerRemoveResponses, type TrackHasScanStationsError, type TrackIdsNotMatchingError, type TrackLapTimeCantBeNegativeError, type TrackNotFoundError, type TrackScan, type UpdateDistanceDonation, type UpdateDonation, type UpdateDonor, type UpdateFixedDonation, type UpdateGroupContact, type UpdatePermission, type UpdateRunner, type UpdateRunnerCard, type UpdateRunnerOrganization, type UpdateRunnerTeam, type UpdateScan, type UpdateScanStation, type UpdateTrack, type UpdateTrackScan, type UpdateUser, type UpdateUserGroup, type User, type UserAction, type UserControllerGetAllData, type UserControllerGetAllResponse, type UserControllerGetAllResponses, type UserControllerGetOneData, type UserControllerGetOneError, type UserControllerGetOneErrors, type UserControllerGetOneResponse, type UserControllerGetOneResponses, type UserControllerGetPermissionsData, type UserControllerGetPermissionsError, type UserControllerGetPermissionsErrors, type UserControllerGetPermissionsResponse, type UserControllerGetPermissionsResponses, type UserControllerPostData, type UserControllerPostError, type UserControllerPostErrors, type UserControllerPostResponse, type UserControllerPostResponses, type UserControllerPutData, type UserControllerPutError, type UserControllerPutErrors, type UserControllerPutResponse, type UserControllerPutResponses, type UserControllerRemoveData, type UserControllerRemoveError, type UserControllerRemoveErrors, type UserControllerRemoveResponse, type UserControllerRemoveResponses, type UserDeletionNotConfirmedError, type UserDisabledError, type UserEmailNeededError, type UserGroup, type UserGroupControllerGetAllData, type UserGroupControllerGetAllResponse, type UserGroupControllerGetAllResponses, type UserGroupControllerGetOneData, type UserGroupControllerGetOneError, type UserGroupControllerGetOneErrors, type UserGroupControllerGetOneResponse, type UserGroupControllerGetOneResponses, type UserGroupControllerGetPermissionsData, type UserGroupControllerGetPermissionsError, type UserGroupControllerGetPermissionsErrors, type UserGroupControllerGetPermissionsResponse, type UserGroupControllerGetPermissionsResponses, type UserGroupControllerPostData, type UserGroupControllerPostResponse, type UserGroupControllerPostResponses, type UserGroupControllerPutData, type UserGroupControllerPutError, type UserGroupControllerPutErrors, type UserGroupControllerPutResponse, type UserGroupControllerPutResponses, type UserGroupControllerRemoveData, type UserGroupControllerRemoveResponse, type UserGroupControllerRemoveResponses, type UserGroupIdsNotMatchingError, type UserGroupNotFoundError, type UserIdsNotMatchingError, type UserNonexistantOrRefreshtokenInvalidError, type UserNotFoundError, type UserNotFoundOrRefreshTokenCountInvalidError, type UsernameContainsIllegalCharacterError, type UsernameOrEmailNeededError, authControllerGetResetToken, authControllerLogin, authControllerLogout, authControllerRefresh, authControllerResetPassword, donationControllerGetAll, donationControllerGetOne, donationControllerPostDistance, donationControllerPostFixed, donationControllerPutDistance, donationControllerPutFixed, donationControllerRemove, donorControllerGetAll, donorControllerGetOne, donorControllerPost, donorControllerPut, donorControllerRemove, groupContactControllerGetAll, groupContactControllerGetOne, groupContactControllerPost, groupContactControllerPut, groupContactControllerRemove, importControllerPostCsv, importControllerPostJson, importControllerPostOrgsCsv, importControllerPostOrgsJson, importControllerPostTeamsCsv, importControllerPostTeamsJson, meControllerGet, meControllerGetPermissions, meControllerPut, meControllerRemove, permissionControllerGetAll, permissionControllerGetOne, permissionControllerPost, permissionControllerPut, permissionControllerRemove, runnerCardControllerGetAll, runnerCardControllerGetOne, runnerCardControllerPost, runnerCardControllerPostBlancoBulk, runnerCardControllerPut, runnerCardControllerRemove, runnerControllerGetAll, runnerControllerGetOne, runnerControllerGetScans, runnerControllerPost, runnerControllerPut, runnerControllerRemove, runnerOrganizationControllerGetAll, runnerOrganizationControllerGetOne, runnerOrganizationControllerGetRunners, runnerOrganizationControllerPost, runnerOrganizationControllerPut, runnerOrganizationControllerRemove, runnerSelfServiceControllerGet, runnerSelfServiceControllerGetScans, runnerSelfServiceControllerGetSelfserviceOrg, runnerSelfServiceControllerGetStationMe, runnerSelfServiceControllerRegisterOrganizationRunner, runnerSelfServiceControllerRegisterRunner, runnerSelfServiceControllerRemove, runnerSelfServiceControllerRequestNewToken, runnerTeamControllerGetAll, runnerTeamControllerGetOne, runnerTeamControllerGetRunners, runnerTeamControllerPost, runnerTeamControllerPut, runnerTeamControllerRemove, scanControllerGetAll, scanControllerGetOne, scanControllerPost, scanControllerPostTrackScans, scanControllerPut, scanControllerPutTrackScan, scanControllerRemove, scanStationControllerGetAll, scanStationControllerGetOne, scanStationControllerPost, scanStationControllerPut, scanStationControllerRemove, statsClientControllerGetAll, statsClientControllerGetOne, statsClientControllerPost, statsClientControllerRemove, statsControllerGet, statsControllerGetTopOrgsByDistance, statsControllerGetTopOrgsByDonations, statsControllerGetTopRunnersByDistance, statsControllerGetTopRunnersByDonations, statsControllerGetTopRunnersByLaptime, statsControllerGetTopRunnersByTrackTime, statsControllerGetTopTeamsByDistance, statsControllerGetTopTeamsByDonations, statusControllerGet, statusControllerGetVersion, trackControllerGetAll, trackControllerGetOne, trackControllerPost, trackControllerPut, trackControllerRemove, userControllerGetAll, userControllerGetOne, userControllerGetPermissions, userControllerPost, userControllerPut, userControllerRemove, userGroupControllerGetAll, userGroupControllerGetOne, userGroupControllerGetPermissions, userGroupControllerPost, userGroupControllerPut, userGroupControllerRemove };
